@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.3.1/Arrangement_on_surface_2/include/CGAL/Arr_accessor.h $
-// $Id: Arr_accessor.h 3849f5e 2020-06-14T00:41:25+03:00 Efi Fogel
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Arrangement_on_surface_2/include/CGAL/Arr_accessor.h $
+// $Id: Arr_accessor.h 6b64dc8 2020-11-11T09:38:55+02:00 Efi Fogel
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -302,13 +302,41 @@ public:
 
   /*!
    * Create a new boundary vertex.
-   * \param cv The curve incident to the boundary.
-   * \param ind The relevant curve-end.
-   * \param ps_x The boundary condition in x.
-   * \param by The boundary condition in y.
+   * \param pt the point
+   * \param ps_x The parameter space in x.
+   * \param ps_y The parameter space in y.
    * \param notify Should we send a notification to the topology traits
    *               on the creation of the vertex (true by default).
-   * \pre Either ps_x or by does not equal ARR_INTERIOR.
+   * \pre One of ps_x or ps_y does not equal ARR_INTERIOR.
+   * \return A handle for the newly created vertex.
+   */
+  Vertex_handle create_boundary_vertex(const Point_2& pt,
+                                       Arr_parameter_space ps_x,
+                                       Arr_parameter_space ps_y,
+                                       bool notify = true)
+  {
+    CGAL_precondition(ps_x != ARR_INTERIOR || ps_y != ARR_INTERIOR);
+
+    DVertex* v = p_arr->_create_boundary_vertex (pt, ps_x, ps_y);
+
+    CGAL_assertion(v != NULL);
+
+    // Notify the topology traits on the creation of the boundary vertex.
+    if (notify)
+      p_arr->topology_traits()->notify_on_boundary_vertex_creation(v, pt,
+                                                                   ps_x, ps_y);
+    return (p_arr->_handle_for(v));
+  }
+
+  /*!
+   * Create a new boundary vertex.
+   * \param cv The curve incident to the boundary.
+   * \param ind The relevant curve-end.
+   * \param ps_x The parameter space in x.
+   * \param ps_y The parameter space in y.
+   * \param notify Should we send a notification to the topology traits
+   *               on the creation of the vertex (true by default).
+   * \pre One of ps_x or ps_y does not equal ARR_INTERIOR.
    * \return A handle for the newly created vertex.
    */
   Vertex_handle create_boundary_vertex(const X_monotone_curve_2& cv,
@@ -317,6 +345,8 @@ public:
                                        Arr_parameter_space ps_y,
                                        bool notify = true)
   {
+    CGAL_precondition(ps_x != ARR_INTERIOR || ps_y != ARR_INTERIOR);
+
     DVertex* v = p_arr->_create_boundary_vertex (cv, ind, ps_x, ps_y);
 
     CGAL_assertion(v != nullptr);
@@ -602,7 +632,7 @@ public:
                                 const X_monotone_curve_2& cv1,
                                 const X_monotone_curve_2& cv2)
   {
-    DHalfedge* he = p_arr->_split_edge (p_arr->_halfedge(e), p, cv1, cv2);
+    DHalfedge* he = p_arr->_split_edge(p_arr->_halfedge(e), p, cv1, cv2);
 
     CGAL_assertion(he != nullptr);
     return (p_arr->_handle_for(he));
