@@ -7,11 +7,13 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Arrangement_on_surface_2/include/CGAL/Arr_polyline_traits_2.h $
-// $Id: Arr_polyline_traits_2.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Arrangement_on_surface_2/include/CGAL/Arr_polyline_traits_2.h $
+// $Id: Arr_polyline_traits_2.h 0ef13b3 2021-09-23T11:10:43+02:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// Author(s)     : Waqar Khan <wkhan@mpi-inf.mpg.de>
+// Author(s): Efi Fogel       <efifogel@gmail.com>
+//            Simon Giraudot  <simon.giraudot@geometryfactory.com>
+//            Waqar Khan      <wkhan@mpi-inf.mpg.de>
 
 #ifndef CGAL_ARR_POLYLINE_TRAITS_2_H
 #define CGAL_ARR_POLYLINE_TRAITS_2_H
@@ -36,6 +38,11 @@
 #include <CGAL/Arr_polycurve_traits_2.h>
 #include <CGAL/Arr_tags.h>
 #include <CGAL/Arr_enums.h>
+#include <CGAL/Single.h>
+
+#include <boost/iterator/zip_iterator.hpp>
+#include <boost/iterator/transform_iterator.hpp>
+#include <boost/range/join.hpp>
 
 namespace CGAL {
 
@@ -69,8 +76,8 @@ public:
   typedef typename Base::Top_side_category            Top_side_category;
   typedef typename Base::Right_side_category          Right_side_category;
 
-  typedef typename Base::Are_all_sides_oblivious_tag
-    Are_all_sides_oblivious_tag;
+  typedef typename Base::All_sides_oblivious_category
+    All_sides_oblivious_category;
 
   typedef typename Base::X_monotone_subcurve_2        X_monotone_subcurve_2;
   typedef typename Base::Subcurve_2                   Subcurve_2;
@@ -96,9 +103,7 @@ public:
   typedef typename Base::Parameter_space_in_x_2       Parameter_space_in_x_2;
   typedef typename Base::Parameter_space_in_y_2       Parameter_space_in_y_2;
   typedef typename Base::Compare_x_on_boundary_2      Compare_x_on_boundary_2;
-  typedef typename Base::Compare_x_at_limit_2         Compare_x_at_limit_2;
   typedef typename Base::Compare_x_near_boundary_2    Compare_x_near_boundary_2;
-  typedef typename Base::Compare_x_near_limit_2       Compare_x_near_limit_2;
   typedef typename Base::Compare_y_on_boundary_2      Compare_y_on_boundary_2;
   typedef typename Base::Compare_y_near_boundary_2    Compare_y_near_boundary_2;
   typedef typename Base::Is_on_y_identification_2     Is_on_y_identification_2;
@@ -300,18 +305,14 @@ public:
     /*! Append a point `p` to an existing polyline `xcv` at the front. */
     void operator()(const X_monotone_curve_2& xcv, Point_2& p) const
     {
-      const Segment_traits_2* geom_traits =
-        this->m_poly_traits.subcurve_traits_2();
+      const auto* geom_traits = this->m_poly_traits.subcurve_traits_2();
       CGAL_precondition_code
         (
          typedef typename X_monotone_curve_2::size_type size_type;
          size_type num_seg = xcv.number_of_subcurves();
-         typename Segment_traits_2::Compare_x_2 comp_x =
-         geom_traits->compare_x_2_object();
-         typename Segment_traits_2::Compare_xy_2 comp_xy =
-         geom_traits->compare_xy_2_object();
-         typename Base::Is_vertical_2 is_vertical =
-           this->m_poly_traits.is_vertical_2_object();
+         auto comp_x = geom_traits->compare_x_2_object();
+         auto comp_xy = geom_traits->compare_xy_2_object();
+         auto is_vertical = this->m_poly_traits.is_vertical_2_object();
          );
       CGAL_precondition(num_seg > 0);
 
@@ -349,7 +350,12 @@ public:
   /*! Obtain a Push_front_2 functor object. */
   Push_front_2 push_front_2_object() const { return Push_front_2(*this); }
 
-  /*! Construct a general curve. */
+  /*! Construct a general curve from :
+   * 1. two points,
+   * 2. a sub curve,
+   * 3. a range of points, or
+   * 4. a range of subcurves.
+   */
   class Construct_curve_2 : public Base::Construct_curve_2 {
   protected:
     typedef Arr_polyline_traits_2<Segment_traits_2>         Polyline_traits_2;
@@ -383,6 +389,13 @@ public:
       return constructor_impl(begin, end, Is_point());
     }
 
+    /* Construct a well-oriented polyline from a range of either
+     * `Segment_traits::Point_2` or `Segment_traits::Subcurve_2`.
+     */
+    template <typename Range>
+    Curve_2 operator()(const Range& range) const
+    { return operator()(range.begin(), range.end()); }
+
     /*! Construction implementation from a range of segments.
      *  Note that the segments in the range are NOT necessarily x-monotone,
      *  thus it is impossible to test (even in precondition) whether the input
@@ -406,33 +419,30 @@ public:
     Curve_2 constructor_impl(ForwardIterator begin, ForwardIterator end,
                              boost::true_type) const
     {
-      // The range must contain at least two points.
-      CGAL_precondition_msg(std::distance(begin, end) > 1,
-                            "Range of points must contain at least 2 points");
+      // The range must not contain a single point.
+      CGAL_precondition_msg(std::distance(begin, end) != 1,
+                            "Range of points must not contain a single point");
 
-      // Container of the segments to be constructed from the range of points
-      std::list<Subcurve_2> segs;
+      using Point_iterator = ForwardIterator;
+      using Zip_iterator =
+        boost::zip_iterator<boost::tuple<Point_iterator, Point_iterator> >;
+      using boost::make_zip_iterator;
+      using Zip_iterator_ref = typename Zip_iterator::reference;
 
-      CGAL_precondition_code
-        (
-         typename Segment_traits_2::Equal_2 equal =
-         this->m_poly_traits.subcurve_traits_2()->equal_2_object();
-         );
-
-      // Check whether there are no points in the range:
-      ForwardIterator next = begin;
-      ForwardIterator curr = next++;
-
-      // Construct a segment from each two adjacent points.
-      Curve_2 cv;
-      while (next != end) {
-        CGAL_precondition_msg(!equal(*curr,*next),
+      CGAL_precondition_code(auto equal = this->m_poly_traits.equal_2_object());
+      auto point_pair_to_segment = [&](const Zip_iterator_ref& t)->Subcurve_2 {
+        CGAL_precondition_msg(! equal(boost::get<0>(t), boost::get<1>(t)),
                               "Cannot construct a degenerated segment");
-        segs.push_back(Subcurve_2(*curr, *next));
-        curr = next++;
-      }
-
-      return operator()(segs.begin(), segs.end());
+        return Subcurve_2(boost::get<0>(t), boost::get<1>(t));
+      };
+      auto begin_next = std::next(begin);
+      auto end_prev = std::prev(end);
+      return operator()(boost::make_transform_iterator
+                        (make_zip_iterator(boost::make_tuple(begin, begin_next)),
+                         point_pair_to_segment),
+                        boost::make_transform_iterator
+                        (make_zip_iterator(boost::make_tuple(end_prev, end)),
+                         point_pair_to_segment));
     }
   };
 
@@ -534,9 +544,9 @@ public:
                                         ForwardIterator end,
                                         boost::true_type) const
     {
-      // The range must contain at least two points.
-      CGAL_precondition_msg(std::distance(begin, end) > 1,
-                            "Range of points must contain at least 2 points");
+      // The range must not contain a single point.
+      CGAL_precondition_msg(std::distance(begin, end) != 1,
+                            "Range of points must not contain a single point");
 
       // Container of the segments to be constructed from the range of points
       std::list<X_monotone_subcurve_2> segs;
@@ -546,13 +556,10 @@ public:
 
       CGAL_precondition_code
         (
-         const Segment_traits_2* geom_traits =
-           this->m_poly_traits.subcurve_traits_2();
+         const auto* geom_traits = this->m_poly_traits.subcurve_traits_2();
          // Initialize two comparison functors
-         typename Segment_traits_2::Compare_x_2 compare_x =
-           geom_traits->compare_x_2_object();
-         typename Segment_traits_2::Compare_xy_2 compare_xy =
-           geom_traits->compare_xy_2_object();
+         auto compare_x = geom_traits->compare_x_2_object();
+         auto compare_xy = geom_traits->compare_xy_2_object();
          // Make sure there is no changed of directions.
          // Saves the comp_x between the first two points
          const Comparison_result cmp_x_res = compare_x(*curr, *next);
