@@ -1,15 +1,16 @@
-// Copyright (c) 2007,2009,2010,2011 Tel-Aviv University (Israel).
+// Copyright (c) 2007,2009,2010,2011,2014 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.3/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_spherical_construction_helper.h $
-// $Id: Arr_spherical_construction_helper.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_spherical_construction_helper.h $
+// $Id: Arr_spherical_construction_helper.h 2d1e009 2021-03-25T12:53:48+02:00 Efi Fogel
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Ron Wein <wein@post.tau.ac.il>
 //                 Efi Fogel <efif@post.tau.ac.il>
+//                 Eric Berberich <eric.berberich@cgal.org>
 
 #ifndef CGAL_ARR_SPHERICAL_CONSTRUCTION_HELPER_H
 #define CGAL_ARR_SPHERICAL_CONSTRUCTION_HELPER_H
@@ -151,6 +152,7 @@ public:
   {
     // If we insert an edge whose right end lies on the north pole, we have
     // to flip the order of predecessor halfegdes.
+    // TODO what about the corner?
     return (event->parameter_space_in_x() == ARR_INTERIOR &&
             event->parameter_space_in_y() == ARR_TOP_BOUNDARY);
   }
@@ -181,35 +183,36 @@ before_handle_event(Event* event)
   Arr_parameter_space ps_y = event->parameter_space_in_y();
   if ((ps_x == ARR_INTERIOR) && (ps_y == ARR_INTERIOR)) return;
 
+  if (event->is_isolated()) return;
+
+  // In the sweep-line event order the events of poles belong to the left and
+  // right boundary. However, here the vertices of the poles are identified by
+  // the event's trais to belong to the bottom and top boundary.
+
   if (ps_y == ARR_BOTTOM_BOUNDARY) {
-    // Process bootom contraction boundary:
-    // The event has only one right curve, as there is exactly one curve
-    // incident to an event with boundary conditions.
-    CGAL_assertion((event->number_of_left_curves() == 0) &&
-                   (event->number_of_right_curves() == 1));
-    const X_monotone_curve_2& xc =
-      (*(event->right_curves_begin()))->last_curve();
+    /* subsumes LEFT-BOTTOM and RIGHT-BOTTOM corner */
+    // Process a non-isolated event on the bottom contracted boundary.
 
     // If a vertex on the south pole does not exists, create one.
     DVertex* dv = m_top_traits->south_pole();
     Vertex_handle v = (dv) ? Vertex_handle(dv) :
-      m_arr_access.create_boundary_vertex(xc, ARR_MIN_END, ps_x, ps_y);
+      m_arr_access.create_boundary_vertex(event->point(), ps_x, ps_y);
     event->set_vertex_handle(v);
     return;
   }
 
   if (ps_y == ARR_TOP_BOUNDARY) {
-    // Process top contraction boundary:
-    // The event has only one left curve, as there is exactly one curve
-    // incident to an event with boundary conditions.
-    CGAL_assertion((event->number_of_left_curves() == 1) &&
-                   (event->number_of_right_curves() == 0));
-    const X_monotone_curve_2& xc =
-      (*(event->left_curves_begin()))->last_curve();
+    /* subsumes LEFT-TOP and RIGHT-TOP corner */
+    // Process a non-isolated event on the top contracted boundary.
+    // The process is more complicated than for the bottom boundary,
+    // as the touching the top boundary influences the list of
+    // halfedges seen in the reference face
 
     DVertex* dv = m_top_traits->north_pole();
     if (dv) {
       event->set_vertex_handle(Vertex_handle(dv));
+      const X_monotone_curve_2& xc =
+        (*(event->left_curves_begin()))->last_curve();
       DHalfedge* dprev =
         m_top_traits->locate_around_boundary_vertex(m_top_traits->north_pole(),
                                                     xc, ARR_MAX_END,
@@ -228,11 +231,11 @@ before_handle_event(Event* event)
       splice_indices_list(prev->next());
       return;
     }
+    // else
 
-    // We do not have a vertex that corresponds to the north pole.
-    // Create one.
+    // If a vertex on the north pole does not exists, create one.
     Vertex_handle v =
-      m_arr_access.create_boundary_vertex(xc, ARR_MAX_END, ps_x, ps_y);
+      m_arr_access.create_boundary_vertex(event->point(), ps_x, ps_y);
     event->set_vertex_handle(v);
 
     // Since this is the first event corresponding to the north pole,
@@ -247,36 +250,28 @@ before_handle_event(Event* event)
   }
 
   if (ps_x == ARR_LEFT_BOUNDARY) {
-    // The event has only right curves, as there is exactly one curve
-    // incident to an event with boundary conditions.
-    CGAL_assertion((event->number_of_left_curves() == 0) &&
-                   (event->number_of_right_curves() >= 1));
-    const X_monotone_curve_2& xc =
-      (*(event->right_curves_begin()))->last_curve();
+    // Process a non-isolated event on the left identified boundary.
+    // It might be the end of a vertical curve.
 
-    // If a vertex on the line of discontinuity does not exists. create one.
-    DVertex* dv = m_top_traits->discontinuity_vertex(xc, ARR_MIN_END);
+    // If a vertex on the line of discontinuity does not exists, create one.
+    DVertex* dv = m_top_traits->discontinuity_vertex(event->point());
     Vertex_handle v = (dv) ? Vertex_handle(dv) :
-      m_arr_access.create_boundary_vertex(xc, ARR_MIN_END, ps_x, ps_y);
+      m_arr_access.create_boundary_vertex(event->point(), ps_x, ps_y);
     event->set_vertex_handle(v);
     return;
   }
 
   if (ps_x == ARR_RIGHT_BOUNDARY) {
-    // The event has only left curves, as there is exactly one curve
-    // incident to an event with boundary conditions.
-    CGAL_assertion((event->number_of_left_curves() >= 1) &&
-                   (event->number_of_right_curves() == 0));
-    const X_monotone_curve_2& xc =
-      (*(event->left_curves_begin()))->last_curve();
-
-    // If a vertex on the line of discontinuity does not exists. create one.
-    DVertex* dv = m_top_traits->discontinuity_vertex(xc, ARR_MAX_END);
+    // Process a non-isolated event on the right identified boundary.
+    // Cannnot be vertical, only curves approaching the right side are possible.
+    // If a vertex on the line of discontinuity does not exists, create one.
+    DVertex* dv = m_top_traits->discontinuity_vertex(event->point());
     Vertex_handle v = (dv) ? Vertex_handle(dv) :
-      m_arr_access.create_boundary_vertex(xc, ARR_MAX_END, ps_x, ps_y);
+      m_arr_access.create_boundary_vertex(event->point(), ps_x, ps_y);
     event->set_vertex_handle(v);
     return;
   }
+
 }
 
 } // namespace CGAL
