@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arrangement_on_surface_2_global.h $
-// $Id: Arrangement_on_surface_2_global.h 09ad8ab 2020-07-02T19:12:43+03:00 Efi Fogel
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arrangement_on_surface_2_global.h $
+// $Id: Arrangement_on_surface_2_global.h 6b64dc8 2020-11-11T09:38:55+02:00 Efi Fogel
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -21,12 +21,12 @@
  * Global insertion functions for the Arrangement_2 class.
  */
 
+#include <list>
 #include <boost/type_traits.hpp>
 #include <boost/mpl/if.hpp>
 #include <boost/type_traits.hpp>
 #include <list>
 
-#include <CGAL/Arrangement_on_surface_2.h>
 #include <CGAL/Arr_accessor.h>
 #include <CGAL/Arrangement_zone_2.h>
 #include <CGAL/Arrangement_2/Arr_compute_zone_visitor.h>
@@ -185,7 +185,7 @@ void insert(Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
   typedef GeometryTraits_2                              Gt2;
   typedef typename Gt2::X_monotone_curve_2              X_monotone_curve_2;
   typedef typename boost::is_same<Curve, X_monotone_curve_2>::type
-    Is_x_monotone;
+                                                        Is_x_monotone;
 
   insert(arr, c, pl, visitor, Is_x_monotone());
 }
@@ -1073,7 +1073,7 @@ remove_edge(Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
     (v_ends[1]->is_at_open_boundary() || (v_ends[1]->degree() == 1));
 
   // Remove the edge from the arrangement.
-  typename Arr::Face_handle    face = arr.remove_edge (e);
+  typename Arr::Face_handle face = arr.remove_edge(e);
 
   // Examine the end-vertices: If a vertex has now two incident edges, and the
   // curves associated with these edges can be merged, merge the two edges and
@@ -1148,7 +1148,7 @@ insert_point(Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
   if (fh != nullptr) {
     // p lies inside a face: Insert it as an isolated vertex it the interior of
     // this face.
-    vh_for_p = arr.insert_in_face_interior(p, arr.non_const_handle (*fh));
+    vh_for_p = arr.insert_in_face_interior(p, arr.non_const_handle(*fh));
   }
   else {
     const Halfedge_const_handle* hh = boost::get<Halfedge_const_handle>(&obj);
@@ -1225,7 +1225,7 @@ bool remove_vertex(Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>&
 
   if (v->is_isolated()) {
     // In case v is an isolated vertex, simply remove it.
-    arr.remove_isolated_vertex (v);
+    arr.remove_isolated_vertex(v);
     removed = true;
   }
   else if (v->degree() == 2) {
@@ -1295,7 +1295,7 @@ is_valid(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr)
   typedef Ss2::Surface_sweep_2<Visitor>                 Surface_sweep_2;
 
   // First use the internal validity check.
-  if (!arr.is_valid()) return (false);
+  if (!arr.is_valid()) return false;
 
   // Perform a sweep over all subcurves associated with arrangement edges.
   std::vector<X_monotone_curve_2> curves_vec(arr.number_of_edges());
@@ -1340,8 +1340,7 @@ is_valid(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr)
       is_first = true;
 
       do {
-        if (ccb->face() != fit)
-          return (false);
+        if (ccb->face() != fit) return false;
 
         if (is_first ||
             compare_xy (ccb->target()->point(), left_v->point()) == SMALLER)
@@ -1354,16 +1353,16 @@ is_valid(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr)
 
       } while (ccb != *ic_it);
 
-      vf_list.push_back (std::make_pair (left_v, fh));
+      vf_list.push_back (std::make_pair(left_v, fh));
     }
 
     // Check all isolated vertices in the current face.
     for (iv_it = fh->isolated_vertices_begin();
          iv_it != fh->isolated_vertices_end(); ++iv_it)
     {
-      if (iv_it->face() != fit) return (false);
+      if (iv_it->face() != fit) return false;
 
-      vf_list.push_back (std::make_pair (Vertex_const_handle(iv_it), fh));
+      vf_list.push_back(std::make_pair(Vertex_const_handle(iv_it), fh));
     }
   }
 
@@ -1416,7 +1415,7 @@ is_valid(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr)
             he_left = he_left->next()->twin();
 
           he_left = he_left->twin()->prev();
-          CGAL_assertion (he_left->direction() == ARR_LEFT_TO_RIGHT);
+          CGAL_assertion(he_left->direction() == ARR_LEFT_TO_RIGHT);
           in_face = he_left->face();
         }
         else if (he_left != invalid_he) {
@@ -1439,8 +1438,7 @@ is_valid(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr)
             // as long as we have he_right halfedge which is below
             he_right = he_curr;
             he_curr = he_right->next()->twin();
-            res = comp_y_at_x_right(he_curr->curve(),
-                                    he_right->curve(),
+            res = comp_y_at_x_right(he_curr->curve(), he_right->curve(),
                                     v_below->point());
           } while(res == SMALLER);
           in_face = he_right->face();
@@ -1456,7 +1454,7 @@ is_valid(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr)
     }
 
     if (vf_iter->second != in_face) {
-      CGAL_warning_msg (false,
+      CGAL_warning_msg(false,
                         "An inner component is located in the wrong face.");
       return false;
     }
@@ -1471,7 +1469,7 @@ is_valid(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr)
 // Meaning, it output the arrangment's vertices, edges and faces that the
 // x-monotone curve intersects.
 template <typename GeometryTraits_2, typename TopologyTraits,
-  typename OutputIterator, typename PointLocation>
+          typename OutputIterator, typename PointLocation>
 OutputIterator
 zone(Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
      const typename GeometryTraits_2::X_monotone_curve_2& c,
