@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/GraphicsView/include/CGAL/Buffer_for_vao.h $
-// $Id: Buffer_for_vao.h 604e352 2020-11-04T20:46:04+01:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/GraphicsView/include/CGAL/Buffer_for_vao.h $
+// $Id: Buffer_for_vao.h 2cbc381 2021-09-23T16:13:57+02:00 Laurent Rineau
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -15,7 +15,7 @@
 
 #include <CGAL/license/GraphicsView.h>
 
-#include <CGAL/Triangulation_2_projection_traits_3.h>
+#include <CGAL/Projection_traits_3.h>
 #include <CGAL/Triangulation_vertex_base_with_info_2.h>
 #include <CGAL/Triangulation_face_base_with_info_2.h>
 #include <CGAL/Constrained_Delaunay_triangulation_2.h>
@@ -244,7 +244,7 @@ public:
 
   // 1.2) Add a point, with color.
   template<typename KPoint>
-  void add_point(const KPoint& kp, const CGAL::Color& c)
+  void add_point(const KPoint& kp, const CGAL::IO::Color& c)
   {
     add_point(kp);
     add_color(c);
@@ -268,7 +268,7 @@ public:
 
   // 2.2) Add a segment, with color.
   template<typename KPoint>
-  void add_segment(const KPoint& kp1, const KPoint& kp2, const CGAL::Color& c)
+  void add_segment(const KPoint& kp1, const KPoint& kp2, const CGAL::IO::Color& c)
   {
     add_segment(kp1, kp2);
     add_color(c);
@@ -294,7 +294,7 @@ public:
   //3.2) Add a ray segment, with color
   template<typename KPoint, typename KVector>
   void add_ray_segment(const KPoint& kp1, const KVector& kp2,
-                       const CGAL::Color& c)
+                       const CGAL::IO::Color& c)
   {
     add_point(kp1);
     add_point_infinity(kp2);
@@ -313,7 +313,7 @@ public:
   // 4.1) Add a line, with color
   template<typename KPoint>
   void add_line_segment(const KPoint& kp1, const KPoint& kp2,
-                        const CGAL::Color& c)
+                        const CGAL::IO::Color& c)
   {
     add_point_infinity(kp1);
     add_point_infinity(kp2);
@@ -330,7 +330,7 @@ public:
   { face_begin_internal(false, false); }
 
   // 3.2) Add a face, with a color, without normal.
-  void face_begin(const CGAL::Color& c)
+  void face_begin(const CGAL::IO::Color& c)
   {
     m_color_of_face=c;
     face_begin_internal(true, false);
@@ -346,7 +346,7 @@ public:
 
   // 3.3) Add a face, with a color and with a normal.
   template<typename KNormal>
-  void face_begin(const CGAL::Color& c, const KNormal& kv)
+  void face_begin(const CGAL::IO::Color& c, const KNormal& kv)
   {
     m_color_of_face=c;
     m_normal_of_face=get_local_vector(kv);
@@ -477,7 +477,7 @@ public:
   }
 
   ///adds `acolor` RGB components to `buffer`
-  static void add_color_in_buffer(const CGAL::Color& acolor, std::vector<float>& buffer)
+  static void add_color_in_buffer(const CGAL::IO::Color& acolor, std::vector<float>& buffer)
   {
     buffer.push_back((float)acolor.red()/(float)255);
     buffer.push_back((float)acolor.green()/(float)255);
@@ -521,17 +521,15 @@ public:
 
       local_orientation=Local_kernel::Orientation_3()(V1, V2, normal) ;
 
-      if(local_orientation!=CGAL::ZERO && local_orientation!=orientation)
-      { return false; }
-      // V1 and V2 are collinear
-      if(local_orientation==CGAL::ZERO )
+      if(local_orientation!=CGAL::ZERO)
       {
-        //TS and TU are opposite
-        if(CGAL::scalar_product(V1,V2) >=0)
-          return true;
-        //TS and TU have the same direction.
-        else
-          return false;
+        if(local_orientation!=orientation)
+        { return false; }
+      }
+      else
+      {
+        if(CGAL::scalar_product(V1,V2)<0)
+        { return false; }  //TS and TU are opposite
       }
     }
     return true;
@@ -837,7 +835,7 @@ protected:
     return is_facet_convex(m_points_of_face, N);
   }
 
-  void add_color(const CGAL::Color& acolor)
+  void add_color(const CGAL::IO::Color& acolor)
   {
     if (m_color_buffer!=nullptr)
     { add_color_in_buffer(acolor, *m_color_buffer); }
@@ -887,7 +885,7 @@ protected:
     bool is_process;
   };
 
-  typedef CGAL::Triangulation_2_projection_traits_3<CGAL::Exact_predicates_inexact_constructions_kernel> P_traits;
+  typedef CGAL::Projection_traits_3<CGAL::Exact_predicates_inexact_constructions_kernel> P_traits;
   typedef CGAL::Triangulation_vertex_base_with_info_2<Vertex_info, P_traits> Vb;
   typedef CGAL::Triangulation_face_base_with_info_2<Face_info, P_traits>     Fb1;
   typedef CGAL::Constrained_triangulation_face_base_2<P_traits, Fb1>         Fb;
@@ -908,7 +906,7 @@ protected:
   bool m_zero_y; /// True iff all points have y==0
   bool m_zero_z; /// True iff all points have z==0
 
-  bool m_inverse_normal;;
+  bool m_inverse_normal;
 
   // Local variables, used when we started a new face.g
   bool m_face_started;
@@ -917,7 +915,7 @@ protected:
   std::vector<Local_point> m_points_of_face;
   std::vector<Local_vector> m_vertex_normals_for_face;
   std::vector<std::size_t> m_indices_of_points_of_face;
-  CGAL::Color m_color_of_face;
+  CGAL::IO::Color m_color_of_face;
   Local_vector m_normal_of_face;
 };
 
