@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.3/STL_Extension/include/CGAL/Concurrent_compact_container.h $
-// $Id: Concurrent_compact_container.h 59a0da4 2021-05-19T17:23:53+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/STL_Extension/include/CGAL/Concurrent_compact_container.h $
+// $Id: Concurrent_compact_container.h e683686 2021-11-18T12:31:39+01:00 Laurent Rineau
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Clement Jamin
@@ -313,10 +313,10 @@ public:
     a.swap(b);
   }
 
-  iterator begin() { return iterator(m_first_item, 0, 0); }
+  iterator begin() { return empty()?end():iterator(m_first_item, 0, 0); }
   iterator end()   { return iterator(m_last_item, 0); }
 
-  const_iterator begin() const { return const_iterator(m_first_item, 0, 0); }
+  const_iterator begin() const { return empty()?end():const_iterator(m_first_item, 0, 0); }
   const_iterator end()   const { return const_iterator(m_last_item, 0); }
 
   reverse_iterator rbegin() { return reverse_iterator(end()); }
@@ -394,10 +394,6 @@ private:
 
     std::allocator_traits<allocator_type>::destroy(m_alloc, &*x);
 
-/* WE DON'T DO THAT BECAUSE OF THE ERASE COUNTER
-#ifndef CGAL_NO_ASSERTIONS
-    std::memset(&*x, 0, sizeof(T));
-#endif*/
     put_on_free_list(&*x, fl);
   }
 public:
