@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Generalized_map/include/CGAL/Generalized_map_fwd.h $
-// $Id: Generalized_map_fwd.h 0308d1a 2020-03-27T18:35:15+01:00 Guillaume Damiand
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Generalized_map/include/CGAL/Generalized_map_fwd.h $
+// $Id: Generalized_map_fwd.h d6306be 2020-10-22T10:30:38+02:00 Guillaume Damiand
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -13,10 +13,11 @@
 #define GENERALIZED_MAP_FWD_H 1
 
 #include <CGAL/memory.h>
+#include <CGAL/tags.h>
 
 namespace CGAL {
 
-template<unsigned int d_, class Items_, class Alloc_ >
+template<unsigned int d_, class Items_, class Alloc_, class Concurrent_tag=CGAL::Tag_false >
 class Generalized_map_storage_1;
 
 struct Generic_map_min_items;
@@ -24,13 +25,13 @@ struct Generic_map_min_items;
 template < unsigned int d_, class Refs,
            class Items_=Generic_map_min_items,
            class Alloc_=CGAL_ALLOCATOR(int),
-           class Storage_= Generalized_map_storage_1<d_, Items_, Alloc_> >
+           class Storage_= Generalized_map_storage_1<d_, Items_, Alloc_, CGAL::Tag_false> >
 class Generalized_map_base;
 
 template < unsigned int d_,
            class Items_=Generic_map_min_items,
            class Alloc_=CGAL_ALLOCATOR(int),
-           class Storage_= Generalized_map_storage_1<d_, Items_, Alloc_> >
+           class Storage_= Generalized_map_storage_1<d_, Items_, Alloc_, CGAL::Tag_false> >
 class Generalized_map;
 
 } // CGAL
