@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.3/Spatial_sorting/include/CGAL/Hilbert_sort_middle_2.h $
-// $Id: Hilbert_sort_middle_2.h 5c41b10 2020-01-02T10:26:44+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Spatial_sorting/include/CGAL/Hilbert_sort_middle_2.h $
+// $Id: Hilbert_sort_middle_2.h 9cd8ca6 2022-04-12T16:34:33+02:00 Laurent Rineau
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     :  Olivier Devillers
@@ -16,7 +16,7 @@
 #include <functional>
 #include <cstddef>
 #include <CGAL/Hilbert_sort_middle_base.h>
-#include <CGAL/Polygon_2_algorithms.h>
+#include <CGAL/number_utils.h>
 
 namespace CGAL {
 
@@ -31,7 +31,7 @@ struct Fixed_hilbert_cmp_2<K,x,true>
   typedef typename K::Point_2 Point;
   K k;
   double value;
-  Fixed_hilbert_cmp_2 (double v, const K &_k = K()) : k(_k),value(v) {}
+  Fixed_hilbert_cmp_2 (double v, const K &_k) : k(_k),value(v) {}
   bool operator() (const Point &p) const
   {
     return ! Fixed_hilbert_cmp_2<K,x,false> (value, k) (p);
@@ -46,7 +46,7 @@ struct Fixed_hilbert_cmp_2<K,0,false>
   typedef typename K::Point_2 Point;
   K k;
   double value;
-  Fixed_hilbert_cmp_2 (double v, const K &_k = K()) : k(_k),value(v) {}
+  Fixed_hilbert_cmp_2 (double v, const K &_k) : k(_k),value(v) {}
   bool operator() (const Point &p) const
   {
     return to_double(k.compute_x_2_object()(p)) < value;
@@ -61,7 +61,7 @@ struct Fixed_hilbert_cmp_2<K,1,false>
   typedef typename K::Point_2 Point;
   K k;
   double value;
-  Fixed_hilbert_cmp_2 (double v, const K &_k = K()) : k(_k),value(v) {}
+  Fixed_hilbert_cmp_2 (double v, const K &_k) : k(_k),value(v) {}
   bool operator() (const Point &p) const
   {
     return to_double(k.compute_y_2_object()(p)) < value;
@@ -89,7 +89,7 @@ private:
   };
 
 public:
-  Hilbert_sort_middle_2 (const Kernel &k = Kernel(), std::ptrdiff_t limit = 1)
+  Hilbert_sort_middle_2 (const Kernel &k, std::ptrdiff_t limit = 1)
     : _k(k), _limit (limit)
   {}
 
@@ -123,22 +123,20 @@ public:
   void operator() (RandomAccessIterator begin, RandomAccessIterator end) const
   {
     //Bbox_2 box=bbox_2(begin, end); BUG: WE NEED TO FIX THIS
-
-    K k;
-    double xmin=to_double(k.compute_x_2_object()(*begin)),
-           ymin=to_double(k.compute_y_2_object()(*begin)),
+    double xmin=to_double(_k.compute_x_2_object()(*begin)),
+           ymin=to_double(_k.compute_y_2_object()(*begin)),
            xmax=xmin,
            ymax=ymin;
 
     for(RandomAccessIterator it=begin+1; it<end; ++it){
-      if ( to_double(k.compute_x_2_object()(*it)) < xmin)
-        xmin = to_double(k.compute_x_2_object()(*it));
-      if ( to_double(k.compute_y_2_object()(*it)) < ymin)
-        ymin = to_double(k.compute_y_2_object()(*it));
-      if ( to_double(k.compute_x_2_object()(*it)) > xmax)
-        xmax = to_double(k.compute_x_2_object()(*it));
-      if ( to_double(k.compute_y_2_object()(*it)) > ymax)
-        ymax = to_double(k.compute_y_2_object()(*it));
+      if ( to_double(_k.compute_x_2_object()(*it)) < xmin)
+        xmin = to_double(_k.compute_x_2_object()(*it));
+      if ( to_double(_k.compute_y_2_object()(*it)) < ymin)
+        ymin = to_double(_k.compute_y_2_object()(*it));
+      if ( to_double(_k.compute_x_2_object()(*it)) > xmax)
+        xmax = to_double(_k.compute_x_2_object()(*it));
+      if ( to_double(_k.compute_y_2_object()(*it)) > ymax)
+        ymax = to_double(_k.compute_y_2_object()(*it));
     }
 
     sort <0, false, false> (begin, end, xmin, ymin, xmax, ymax);
