@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Homogeneous_kernel/include/CGAL/Homogeneous/Aff_transformationH2.h $
-// $Id: Aff_transformationH2.h 9a3e038 2020-05-18T12:24:25+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Homogeneous_kernel/include/CGAL/Homogeneous/Aff_transformationH2.h $
+// $Id: Aff_transformationH2.h d370326 2021-10-27T14:45:10+02:00 Sébastien Loriot
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -58,6 +58,11 @@ class Aff_transformation_rep_baseH2 : public Ref_counted_virtual
                         general_form() const = 0;
     virtual  bool       is_even() const = 0;
 
+    virtual  bool       is_translation() const { return false; }
+    virtual  bool       is_scaling() const { return false; }
+    virtual  bool       is_reflection() const { return false; }
+    virtual  bool       is_rotation() const { return false; }
+
     virtual  RT         homogeneous(int i, int j) const = 0;
     virtual  FT         cartesian(int i, int j) const = 0;
 };
@@ -247,6 +252,10 @@ class Translation_repH2 : public Aff_transformation_rep_baseH2<R>
              is_even() const
              { return true; }
 
+    virtual  bool
+             is_translation() const
+             { return true; }
+
     virtual  Aff_transformation_repH2<R>
              general_form() const
              {
@@ -321,6 +330,11 @@ class Rotation_repH2 : public Aff_transformation_rep_baseH2<R>
              {
                return true;
              }
+
+    virtual  bool
+             is_rotation() const
+             { return true; }
+
     virtual  Aff_transformation_repH2<R>
              general_form() const
              {
@@ -392,6 +406,10 @@ class Scaling_repH2 : public Aff_transformation_rep_baseH2<R>
              is_even() const
              { return true; }
 
+    virtual  bool
+             is_scaling() const
+             { return true; }
+
     virtual  Aff_transformation_repH2<R>
              general_form() const
              {
@@ -456,6 +474,10 @@ class Reflection_repH2 : public Aff_transformation_rep_baseH2<R>
              is_even() const
              { return false; }
 
+    virtual  bool
+             is_reflection() const
+             { return true; }
+
     virtual  Aff_transformation_repH2<R>
              general_form() const
              {
@@ -576,6 +598,11 @@ public:
     bool                    is_even() const;
     bool                    is_odd()  const;
 
+    bool                    is_translation() const;
+    bool                    is_scaling() const;
+    bool                    is_rotation() const;
+    bool                    is_reflection() const;
+
                             // Access functions for matrix form
     FT                      cartesian(int i, int j) const;
     RT                      homogeneous(int i, int j) const;
@@ -739,6 +766,30 @@ Aff_transformationH2<R>::
 is_odd() const
 { return ! is_even(); }
 
+template < class R >
+bool
+Aff_transformationH2<R>::
+is_translation() const
+{ return this->Ptr()->is_translation(); }
+
+template < class R >
+bool
+Aff_transformationH2<R>::
+is_scaling() const
+{ return this->Ptr()->is_scaling(); }
+
+template < class R >
+bool
+Aff_transformationH2<R>::
+is_rotation() const
+{ return this->Ptr()->is_rotation(); }
+
+template < class R >
+bool
+Aff_transformationH2<R>::
+is_reflection() const
+{ return this->Ptr()->is_reflection(); }
+
 template < class R >
 inline
 typename Aff_transformationH2<R>::FT
@@ -805,7 +856,7 @@ Aff_transformation_repH2<R>::homogeneous(int i, int j) const
               case 0: return a;
               case 1: return b;
               case 2: return c;
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 1: switch (j)
@@ -813,7 +864,7 @@ Aff_transformation_repH2<R>::homogeneous(int i, int j) const
               case 0: return d;
               case 1: return e;
               case 2: return f;
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 2: switch (j)
@@ -821,10 +872,10 @@ Aff_transformation_repH2<R>::homogeneous(int i, int j) const
               case 0: return RT(0);
               case 1: return RT(0);
               case 2: return g;
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
   }
-  CGAL_assume(false);
+  CGAL_unreachable();
   return RT(0);
 }
 
@@ -849,7 +900,7 @@ Translation_repH2<R>::homogeneous(int i, int j) const
               case 0: return _tv.hw();
               case 1: return RT(0);
               case 2: return _tv.hx();
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 1: switch (j)
@@ -857,7 +908,7 @@ Translation_repH2<R>::homogeneous(int i, int j) const
               case 0: return RT(0);
               case 1: return _tv.hw();
               case 2: return _tv.hy();
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 2: switch (j)
@@ -865,10 +916,10 @@ Translation_repH2<R>::homogeneous(int i, int j) const
               case 0: return RT(0);
               case 1: return RT(0);
               case 2: return _tv.hw();
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
   }
-  CGAL_assume(false);
+  CGAL_unreachable();
   return RT(0);
 }
 
@@ -884,7 +935,7 @@ Translation_repH2<R>::cartesian(int i, int j) const
               case 0: return FT(1);
               case 1: return FT(0);
               case 2: return _tv.x();
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 1: switch (j)
@@ -892,7 +943,7 @@ Translation_repH2<R>::cartesian(int i, int j) const
               case 0: return FT(0);
               case 1: return FT(1);
               case 2: return _tv.y();
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 2: switch (j)
@@ -900,10 +951,10 @@ Translation_repH2<R>::cartesian(int i, int j) const
               case 0: return FT(0);
               case 1: return FT(0);
               case 2: return FT(1);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
   }
-  CGAL_assume(false);
+  CGAL_unreachable();
   return FT(0);
 }
 
@@ -920,7 +971,7 @@ homogeneous(int i, int j) const
               case 0: return _cos;
               case 1: return - _sin;
               case 2: return RT(0);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 1: switch (j)
@@ -928,7 +979,7 @@ homogeneous(int i, int j) const
               case 0: return _sin;
               case 1: return _cos;
               case 2: return RT(0);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 2: switch (j)
@@ -936,10 +987,10 @@ homogeneous(int i, int j) const
               case 0: return RT(0);
               case 1: return RT(0);
               case 2: return _den;
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
   }
-  CGAL_assume(false);
+  CGAL_unreachable();
   return RT(0);
 }
 
@@ -956,7 +1007,7 @@ cartesian(int i, int j) const
               case 0: return FT(_cos) / FT(_den);
               case 1: return - FT(_sin) / FT(_den);
               case 2: return FT(0);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 1: switch (j)
@@ -964,7 +1015,7 @@ cartesian(int i, int j) const
               case 0: return FT(_sin) / FT(_den);
               case 1: return FT(_cos) / FT(_den);
               case 2: return FT(0);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 2: switch (j)
@@ -972,10 +1023,10 @@ cartesian(int i, int j) const
               case 0: return FT(0);
               case 1: return FT(0);
               case 2: return FT(1);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
   }
-  CGAL_assume(false);
+  CGAL_unreachable();
   return FT(0);
 }
 
@@ -992,7 +1043,7 @@ homogeneous(int i, int j) const
               case 0: return _sf_num;
               case 1: return RT(0);
               case 2: return RT(0);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 1: switch (j)
@@ -1000,7 +1051,7 @@ homogeneous(int i, int j) const
               case 0: return RT(0);
               case 1: return _sf_num;
               case 2: return RT(0);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 2: switch (j)
@@ -1008,10 +1059,10 @@ homogeneous(int i, int j) const
               case 0: return RT(0);
               case 1: return RT(0);
               case 2: return _sf_den;
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
   }
-  CGAL_assume(false);
+  CGAL_unreachable();
   return RT(0);
 }
 
@@ -1028,7 +1079,7 @@ cartesian(int i, int j) const
               case 0: return FT(_sf_num) / FT(_sf_den);
               case 1: return FT(0);
               case 2: return FT(0);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 1: switch (j)
@@ -1036,7 +1087,7 @@ cartesian(int i, int j) const
               case 0: return FT(0);
               case 1: return FT(_sf_num) / FT(_sf_den);
               case 2: return FT(0);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 2: switch (j)
@@ -1044,10 +1095,10 @@ cartesian(int i, int j) const
               case 0: return FT(0);
               case 1: return FT(0);
               case 2: return FT(1);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
   }
-  CGAL_assume(false);
+  CGAL_unreachable();
   return FT(0);
 }
 
@@ -1065,7 +1116,7 @@ homogeneous(int i, int j) const
               case 0: return l.b()*l.b() - l.a()*l.a();
               case 1: return l.a()*l.b()*mRT2;
               case 2: return l.a()*l.c()*mRT2;
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 1: switch (j)
@@ -1073,7 +1124,7 @@ homogeneous(int i, int j) const
               case 0: return l.a()*l.b()*mRT2;
               case 1: return l.a()*l.a() - l.b()*l.b();
               case 2: return l.b()*l.c()*mRT2;
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 2: switch (j)
@@ -1081,10 +1132,10 @@ homogeneous(int i, int j) const
               case 0: return RT(0);
               case 1: return RT(0);
               case 2: return l.a()*l.a() + l.b()*l.b();
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
   }
-  CGAL_assume(false);
+  CGAL_unreachable();
   return RT(0);
 }
 
@@ -1102,7 +1153,7 @@ cartesian(int i, int j) const
               case 0: return FT( l.b()-l.a() ) / FT( l.a()+l.b());
               case 1: return FT( homogeneous(0,1)) / de;
               case 2: return FT( homogeneous(0,2)) / de;
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 1: switch (j)
@@ -1110,7 +1161,7 @@ cartesian(int i, int j) const
               case 0: return FT( homogeneous(1,0)) / de;
               case 1: return FT( l.a()-l.b() ) / FT( l.a()+l.b());
               case 2: return FT( homogeneous(1,2)) / de;
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
             break;
     case 2: switch (j)
@@ -1118,10 +1169,10 @@ cartesian(int i, int j) const
               case 0: return FT(0);
               case 1: return FT(0);
               case 2: return FT(1);
-              default: CGAL_assume(false);
+              default: CGAL_unreachable();
             }
   }
-  CGAL_assume(false);
+  CGAL_unreachable();
   return FT(0);
 }
 
