@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.3/Polyhedron/include/CGAL/IO/Polyhedron_iostream.h $
-// $Id: Polyhedron_iostream.h 0149977 2020-10-23T09:10:53+02:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Polyhedron/include/CGAL/IO/Polyhedron_iostream.h $
+// $Id: Polyhedron_iostream.h 115fa5a 2021-12-14T14:01:21+00:00 Andreas Fabri
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,9 +18,6 @@
 #include <CGAL/IO/Polyhedron_OFF_iostream.h>
 #include <CGAL/IO/Polyhedron_VRML_1_ostream.h>
 #include <CGAL/IO/Polyhedron_VRML_2_ostream.h>
-#ifdef CGAL_USE_GEOMVIEW
-#include <CGAL/IO/Polyhedron_geomview_ostream.h>
-#endif
 
 #include <CGAL/IO/Polyhedron_inventor_ostream.h>
 
