@@ -6,8 +6,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.3/Stream_support/include/CGAL/IO/WKT/traits_multipolygon.h $
-// $Id: traits_multipolygon.h 490a726 2020-01-20T10:42:46+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Stream_support/include/CGAL/IO/WKT/traits_multipolygon.h $
+// $Id: traits_multipolygon.h 98e4718 2021-08-26T11:33:39+02:00 Sébastien Loriot
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Maxime Gimeno
@@ -15,9 +15,7 @@
 #ifndef CGAL_IO_WKT_TRAITS_MULTIPOLYGON_H
 #define CGAL_IO_WKT_TRAITS_MULTIPOLYGON_H
 
-#if BOOST_VERSION >= 105600 && (! defined(BOOST_GCC) || BOOST_GCC >= 40500)
-
-#include <CGAL/internal/Geometry_container.h>
+#include <CGAL/Stream_support/internal/Geometry_container.h>
 
 #include <boost/geometry/io/wkt/write.hpp>
 #include <boost/geometry/io/wkt/read.hpp>
@@ -37,6 +35,5 @@ struct tag<CGAL::internal::Geometry_container<R, multi_polygon_tag> >
 } // namespace geometry
 } // namespace boost
 
-#endif // BOOST VERSION CHECKS
 #endif // CGAL_IO_WKT_TRAITS_MULTIPOLYGON_H
 
