@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Intersections_2/include/CGAL/Intersections_2/Circle_2_Ray_2.h $
-// $Id: Circle_2_Ray_2.h ce4cbe6 2020-03-19T11:41:57+01:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Intersections_2/include/CGAL/Intersections_2/Circle_2_Ray_2.h $
+// $Id: Circle_2_Ray_2.h 7e62c02 2021-04-12T14:02:37+02:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -13,10 +13,11 @@
 #ifndef CGAL_INTERSECTIONS_2_CIRCLE_2_RAY_2_H
 #define CGAL_INTERSECTIONS_2_CIRCLE_2_RAY_2_H
 
+#include <CGAL/Distance_2/Point_2_Ray_2.h>
+#include <CGAL/Intersection_traits_2.h>
+
 #include <CGAL/Circle_2.h>
 #include <CGAL/Ray_2.h>
-#include <CGAL/squared_distance_2_1.h>
-#include <CGAL/Intersection_traits_2.h>
 
 namespace CGAL {
 namespace Intersections {
