@@ -1,10 +1,16 @@
-// Copyright (c) 2010 GeometryFactory (France).
+// Copyright (c) 1997-2021
+// Utrecht University (The Netherlands),
+// ETH Zurich (Switzerland),
+// INRIA Sophia-Antipolis (France),
+// Max-Planck-Institute Saarbruecken (Germany),
+// and Tel-Aviv University (Israel).
+// GeometryFactory (France)
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Intersections_3/include/CGAL/Intersections_3/Triangle_3_Triangle_3.h $
-// $Id: Triangle_3_Triangle_3.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Intersections_3/include/CGAL/Intersections_3/Triangle_3_Triangle_3.h $
+// $Id: Triangle_3_Triangle_3.h c2d1adf 2021-06-23T17:34:48+02:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,12 +22,14 @@
 
 #include <CGAL/Triangle_3.h>
 
-#include <CGAL/Intersections_3/internal/Triangle_3_Triangle_3_intersection.h>
 #include <CGAL/Intersections_3/internal/Triangle_3_Triangle_3_do_intersect.h>
+#include <CGAL/Intersections_3/internal/Triangle_3_Triangle_3_intersection.h>
 
 namespace CGAL {
-CGAL_INTERSECTION_FUNCTION_SELF(Triangle_3, 3)
+
 CGAL_DO_INTERSECT_FUNCTION_SELF(Triangle_3, 3)
-}
+CGAL_INTERSECTION_FUNCTION_SELF(Triangle_3, 3)
+
+} // namespace CGAL
 
 #endif // CGAL_INTERSECTIONS_3_TRIANGLE_3_TRIANGLE_3_H
