@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Kernel_23/include/CGAL/Kernel/Type_mapper.h $
-// $Id: Type_mapper.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Kernel_23/include/CGAL/Kernel/Type_mapper.h $
+// $Id: Type_mapper.h 3127190 2020-12-08T12:48:04+01:00 Dmitry Anisimov
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -87,9 +87,13 @@ BOOST_PP_REPEAT_FROM_TO(1, 10, CGAL_VARIANT_TYPEMAP, _)
 //};
 
 // Then we specialize for all kernel objects.
+// More details on why it is like that are here: https://github.com/CGAL/cgal/pull/4878#discussion_r459986501
 #define CGAL_Kernel_obj(X) \
   template < typename K1, typename K2 > \
   struct Type_mapper_impl < typename K1::X, K1, K2 > \
+  { typedef typename K2::X type; }; \
+  template < typename K1, typename K2 > \
+  struct Type_mapper_impl < typename K1::X::Rep, K1, K2 > \
   { typedef typename K2::X type; };
 
 #include <CGAL/Kernel/interface_macros.h>
