@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.3/Mesh_3/include/CGAL/Mesh_3/squared_distance_Point_3_Triangle_3.h $
-// $Id: squared_distance_Point_3_Triangle_3.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Mesh_3/include/CGAL/Mesh_3/squared_distance_Point_3_Triangle_3.h $
+// $Id: squared_distance_Point_3_Triangle_3.h 5deb509 2021-04-12T14:42:44+02:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,7 +16,6 @@
 
 #include <CGAL/license/Mesh_3.h>
 
-
-#include <CGAL/squared_distance_3_2.h>
+#include <CGAL/Distance_3/Point_3_Triangle_3.h>
 
 #endif // CGAL_SQUARED_DISTANCE_POINT_3_TRIANGLE_3_H
