@@ -4,12 +4,16 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Number_types/include/CGAL/Mpzf.h $
-// $Id: Mpzf.h c15d630 2020-05-14T10:49:12+02:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Number_types/include/CGAL/Mpzf.h $
+// $Id: Mpzf.h 6481cb2 2021-08-13T16:44:53+02:00 Sébastien Loriot
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)        :  Marc Glisse
 
+#ifndef CGAL_NO_MPZF_DIVISION_OPERATOR
+#define CGAL_MPZF_DIVISION_OPERATOR 1
+#endif
+
 #ifndef CGAL_MPZF_H
 #define CGAL_MPZF_H
 #include <cstdlib>
@@ -108,16 +112,9 @@
 #if !defined(CGAL_HAS_THREADS)
 #define CGAL_MPZF_THREAD_LOCAL
 #define CGAL_MPZF_TLS
-#elif defined(CGAL_CAN_USE_CXX11_THREAD_LOCAL)
+#else
 #define CGAL_MPZF_THREAD_LOCAL thread_local
 #define CGAL_MPZF_TLS thread_local
-#elif defined(_MSC_VER)
-#define CGAL_MPZF_THREAD_LOCAL __declspec(thread)
-#define CGAL_MPZF_TLS
-#else
-#define CGAL_MPZF_THREAD_LOCAL __thread
-#define CGAL_MPZF_TLS
-// Too bad for the others
 #endif
 namespace CGAL {
 namespace Mpzf_impl {
@@ -158,7 +155,6 @@ template <class T, class = void> struct pool2 {
   static T& ptr(T t) { t -= extra+1; return *reinterpret_cast<T*>(t); }
 };
 
-#if defined(CGAL_CAN_USE_CXX11_THREAD_LOCAL)
 template <class T, class = void> struct pool3 {
   static T pop() { T ret = data(); data() = ptr(data()); return ret; }
   static void push(T t) { ptr(t) = data(); data() = t; }
@@ -181,7 +177,6 @@ template <class T, class = void> struct pool3 {
   }
   static T& ptr(T t) { t -= extra+1; return *reinterpret_cast<T*>(t); }
 };
-#endif
 
 // No caching
 template <class T, class = void> struct no_pool {
@@ -281,7 +276,9 @@ struct Mpzf {
       if(data()[-1] >= mini) return; // TODO: when mini==2, no need to check
       delete[] (data() - (pool::extra+1)); // too small, useless
     }
+#ifndef CGAL_MPZF_USE_CACHE
     if(mini<2) mini=2;
+#endif
     data() = (new mp_limb_t[mini+(pool::extra+1)]) + (pool::extra+1);
     data()[-1] = mini;
   }
@@ -772,7 +769,11 @@ struct Mpzf {
     return res;
   }
 
+#ifndef CGAL_MPZF_DIVISION_OPERATOR
+  friend Mpzf division(Mpzf const&a, Mpzf const&b){
+#else // CGAL_MPZF_DIVISION_OPERATOR
   friend Mpzf operator/(Mpzf const&a, Mpzf const&b){
+#endif // CGAL_MPZF_DIVISION_OPERATOR
     // FIXME: Untested
     int asize=std::abs(a.size);
     int bsize=std::abs(b.size);
@@ -907,7 +908,9 @@ struct Mpzf {
   Mpzf& operator+=(Mpzf const&x){ *this=*this+x; return *this; }
   Mpzf& operator-=(Mpzf const&x){ *this=*this-x; return *this; }
   Mpzf& operator*=(Mpzf const&x){ *this=*this*x; return *this; }
+#ifdef CGAL_MPZF_DIVISION_OPERATOR
   Mpzf& operator/=(Mpzf const&x){ *this=*this/x; return *this; }
+#endif // not CGAL_MPZF_DIVISION_OPERATOR
 
   bool is_canonical () const {
     if (size == 0) return true;
@@ -1094,7 +1097,11 @@ std::istream& operator>> (std::istream& is, Mpzf& a)
           Type operator()(
               const Type& x,
               const Type& y ) const {
+#ifdef CGAL_MPZF_DIVISION_OPERATOR
             return x / y;
+#else // not CGAL_MPZF_DIVISION_OPERATOR
+            return division(x, y);
+#endif // not CGAL_MPZF_DIVISION_OPERATOR
           }
         };
 
