@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Nef_3/include/CGAL/Nef_3/K3_tree.h $
-// $Id: K3_tree.h 8bb22d5 2020-03-26T14:23:37+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Nef_3/include/CGAL/Nef_3/K3_tree.h $
+// $Id: K3_tree.h b85aaab 2021-09-29T11:47:01+02:00 Laurent Rineau
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -22,15 +22,8 @@
 #include <CGAL/Nef_3/quotient_coordinates_to_homogeneous_point.h>
 #include <CGAL/Lazy_kernel.h>
 #include <CGAL/Cartesian.h>
+#include <boost/container/deque.hpp>
 
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-#include <CGAL/Constrained_triangulation_2.h>
-#include <CGAL/Triangulation_data_structure_2.h>
-#include <CGAL/Projection_traits_xy_3.h>
-#include <CGAL/Projection_traits_yz_3.h>
-#include <CGAL/Projection_traits_xz_3.h>
-#include <CGAL/Constrained_triangulation_face_base_2.h>
-#endif
 
 #include <deque>
 #include <sstream>
@@ -43,41 +36,6 @@
 
 namespace CGAL {
 
-template <typename Triangle_3>
-void sort_triangle_by_lexicographically_smaller_vertex
-(const Triangle_3& t, int& a, int& b, int& c) {
-  typedef typename Triangle_3::R Kernel;
-  a = 0;
-  for( int i = 1; i < 3; ++i) {
-    if( compare_xyz<Kernel>( t[a], t[i]) == SMALLER)
-      a = i;
-  }
-  b = (a + 1) % 3;
-  c = (b + 1) % 3;
-  if( compare_xyz<Kernel>( t[b], t[c]) == LARGER)
-    std::swap( b, c);
-  return;
-}
-
-template <typename Triangle_3>
-struct Compare_triangle_3 {
-  typedef typename Triangle_3::R Kernel;
-  bool operator()( const Triangle_3& t1, const Triangle_3& t2) const {
-    int v1[3], v2[3];
-    sort_triangle_by_lexicographically_smaller_vertex
-      ( t1, v1[0], v1[1], v1[2]);
-    sort_triangle_by_lexicographically_smaller_vertex
-      ( t2, v2[0], v2[1], v2[2]);
-    for( int i = 0; i < 3; ++i) {
-      Comparison_result c = compare_xyz<Kernel>( t1[v1[i]], t2[v2[i]]);
-      if( c == SMALLER)
-        return true;
-      else if( c == LARGER)
-        return false;
-    }
-    return false; // the two triangles are equivalent
-  }
-};
 
 template <class Traits>
 class K3_tree
@@ -158,94 +116,10 @@ private:
   Coordinate coord;
 };
 
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-  template<typename SNC_structure, typename Kernel>
-  class Triangulation_handler {
-
-    typedef typename CGAL::Triangulation_vertex_base_2<Kernel>                      Vb;
-    typedef typename CGAL::Constrained_triangulation_face_base_2<Kernel>            Fb;
-    typedef typename CGAL::Triangulation_data_structure_2<Vb,Fb>                    TDS;
-    typedef typename CGAL::No_constraint_intersection_requiring_constructions_tag   Itag;
-    typedef typename CGAL::Constrained_triangulation_2<Kernel,TDS,Itag>             CT;
-
-    typedef typename CT::Face_handle           Face_handle;
-    typedef typename CT::Finite_faces_iterator Finite_face_iterator;
-    typedef typename CT::Edge                  Edge;
-
-    typedef typename SNC_structure::Halffacet_cycle_iterator
-                                    Halffacet_cycle_iterator;
-    typedef typename SNC_structure::SHalfedge_around_facet_circulator
-                                    SHalfedge_around_facet_circulator;
-
-    CT ct;
-    CGAL::Unique_hash_map<Face_handle, bool> visited;
-    Finite_face_iterator fi;
-
-  public:
-    template<typename Halffacet_handle>
-    Triangulation_handler(Halffacet_handle f) : visited(false) {
-
-      typedef typename SNC_structure::Halffacet_cycle_iterator
-                                      Halffacet_cycle_iterator;
-      typedef typename SNC_structure::SHalfedge_around_facet_circulator
-                                      SHalfedge_around_facet_circulator;
-
-      Halffacet_cycle_iterator fci;
-      for(fci=f->facet_cycles_begin(); fci!=f->facet_cycles_end(); ++fci) {
-        if(fci.is_shalfedge()) {
-          SHalfedge_around_facet_circulator sfc(fci), send(sfc);
-          CGAL_For_all(sfc,send) {
-            ct.insert_constraint(sfc->source()->source()->point(),
-                                 sfc->source()->twin()->source()->point());
-          }
-        }
-      }
-      CGAL_assertion(ct.is_valid());
-
-      typename CT::Face_handle infinite = ct.infinite_face();
-      typename CT::Vertex_handle ctv = infinite->vertex(1);
-      if(ct.is_infinite(ctv)) ctv = infinite->vertex(2);
-      CGAL_assertion(!ct.is_infinite(ctv));
-
-      typename CT::Face_handle opposite;
-      typename CT::Face_circulator vc(ctv,infinite);
-      do { opposite = vc++;
-      } while(!ct.is_constrained(CT::Edge(vc,vc->index(opposite))));
-      typename CT::Face_handle first = vc;
-
-      traverse_triangulation(first, first->index(opposite));
-
-      fi = ct.finite_faces_begin();
-    }
-
-    void traverse_triangulation(Face_handle f, int parent) {
-      visited[f] = true;
-      if(!ct.is_constrained(Edge(f,ct.cw(parent))) && !visited[f->neighbor(ct.cw(parent))]) {
-        Face_handle child(f->neighbor(ct.cw(parent)));
-        traverse_triangulation(child, child->index(f));
-      }
-      if(!ct.is_constrained(Edge(f,ct.cw(parent))) && !visited[f->neighbor(ct.cw(parent))]) {
-        Face_handle child(f->neighbor(ct.cw(parent)));
-        traverse_triangulation(child, child->index(f));
-      }
-    }
-
-    template<typename Triangle_3>
-    bool get_next_triangle(Triangle_3& tr) {
-      if(fi == ct.finite_faces_end()) return false;
-      ++fi;
-      while(fi != ct.finite_faces_end() && visited[fi] == false) ++fi;
-      if(fi == ct.finite_faces_end()) return false;
-      tr = Triangle_3(fi->vertex(0)->point(), fi->vertex(1)->point(), fi->vertex(2)->point());
-      return true;
-    }
-  };
-#endif
 
 public:
   friend class Objects_along_ray;
   friend class Objects_around_segment;
-  friend class Objects_around_box;
 
 public:
 
@@ -254,12 +128,6 @@ typedef typename Traits::Infimaximal_box Infimaximal_box;
 typedef typename Traits::Vertex_handle Vertex_handle;
 typedef typename Traits::Halfedge_handle Halfedge_handle;
 typedef typename Traits::Halffacet_handle Halffacet_handle;
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-typedef typename Traits::Halffacet_triangle_handle Halffacet_triangle_handle;
-#endif
-#ifdef CGAL_NEF3_FACET_WITH_BOX
-typedef typename Traits::Partial_facet Partial_facet;
-#endif
 typedef typename Traits::Object_handle Object_handle;
 typedef std::vector<Object_handle> Object_list;
 typedef typename Object_list::const_iterator Object_const_iterator;
@@ -288,99 +156,42 @@ typedef Smaller_than<
   Vertex_handle,
   int> Smaller_;
 
-class Node {
+  class Node  {
   friend class K3_tree<Traits>;
 public:
-  Node( Node* p, Node* l, Node* r, Plane_3 pl, const Object_list& O) :
+    typedef Node* Node_handle;
+
+  Node( Node_handle p, Node_handle l, Node_handle r, Plane_3 pl, const Object_list& O) :
     parent_node(p), left_node(l), right_node(r), splitting_plane(pl),
         object_list(O) {
-    if(l == 0)
+    if(l == nullptr)
       point_on_plane = Point_3();
     else
       point_on_plane = pl.point();
   }
   bool is_leaf() const {
-    CGAL_assertion( (left_node != 0 && right_node != 0) ||
-                    (left_node == 0 && right_node == 0));
-    return (left_node == 0 && right_node == 0);
+    CGAL_assertion( (left_node != nullptr && right_node != nullptr) ||
+                    (left_node == nullptr && right_node == nullptr));
+    return (left_node == nullptr && right_node == nullptr);
   }
-  const Node* parent() const { return parent_node; }
-  const Node* left() const { return left_node; }
-  const Node* right() const { return right_node; }
+  Node_handle parent() const { return parent_node; }
+  Node_handle left() const { return left_node; }
+  Node_handle right() const { return right_node; }
   const Plane_3& plane() const { return splitting_plane; }
   const Object_list& objects() const { return object_list; }
 
   void transform(const Aff_transformation_3& t) {
-    if(left_node != 0) {
-        CGAL_assertion(right_node != 0);
+    if(left_node != nullptr) {
+        CGAL_assertion(right_node != nullptr);
         left_node->transform(t);
          right_node->transform(t);
           splitting_plane = splitting_plane.transform(t);
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-    } else {
-      Halffacet_triangle_handle tri;
-      typename Object_list::iterator o;
-      for(o = object_list.begin(); o != object_list.end(); ++o)
-        if(assign(tri,*o)) {
-          tri.transform(t);
-          *o = make_object(tri);
-        }
-#endif // CGAL_NEF3_TRIANGULATE_FACETS
     }
   }
 
-  std::size_t bytes() {
-    // bytes used for the Kd-tree
-    std::size_t s = sizeof(Node);
-    if(left_node != 0)
-      s += left_node->bytes();
-    if(right_node != 0)
-      s += right_node->bytes();
-    typename Object_list::iterator o;
-    for(o = object_list.begin(); o != object_list.end(); ++o)
-      s += sizeof(*o);
-    return s;
-  }
-
-  std::size_t leafs(int mask = 255, int lower_limit = 0) {
-    std::size_t s = 0;
-    Halffacet_handle f;
-    Halfedge_handle e;
-    Vertex_handle v;
-    typename Object_list::iterator o;
-    if(mask == 0)
-      s = 1;
-    else {
-      for(o = object_list.begin(); o != object_list.end(); ++o) {
-        if((mask & 1) && assign(v,*o))
-          ++s;
-        else if((mask&2) && assign(e,*o))
-          ++s;
-        else if(((mask&4) || (mask&8)) && assign(f,*o)) {
-          if(mask&4)
-            ++s;
-          else {
-            int length = 0;
-            typename Traits::SHalfedge_around_facet_circulator safc(f->facet_cycles_begin()),
-              send(safc);
-            while(++length < lower_limit && ++safc != send) ;
-            if(length >= lower_limit)
-              ++s;
-          }
-        }
-      }
-    }
-
-    if(left_node != 0)
-      s += left_node->leafs(mask, lower_limit);
-    if(right_node != 0)
-      s += right_node->leafs(mask, lower_limit);
-    return s;
-  }
-
   template<typename Depth>
   void add_facet(Halffacet_handle f, Depth depth) {
-    if(left_node == 0) {
+    if(left_node == nullptr) {
       object_list.push_back(make_object(f));
       return;
     }
@@ -395,7 +206,7 @@ public:
 
   template<typename Depth>
   void add_edge(Halfedge_handle e, Depth depth) {
-    if(left_node == 0) {
+    if(left_node == nullptr) {
       object_list.push_back(make_object(e));
       return;
     }
@@ -410,7 +221,7 @@ public:
 
   template<typename Depth>
   void add_vertex(Vertex_handle v, Depth depth) {
-    if(left_node == 0) {
+    if(left_node == nullptr) {
       object_list.push_back(make_object(v));
       return;
     }
@@ -425,8 +236,8 @@ public:
 
 
 friend std::ostream& operator<<
-  (std::ostream& os, const Node* node) {
-  CGAL_assertion( node != 0);
+  (std::ostream& os, const Node_handle node) {
+  CGAL_assertion( node != nullptr);
   if( node->is_leaf())
     os <<  node->objects().size();
   else {
@@ -441,24 +252,32 @@ friend std::ostream& operator<<
   return os;
 }
 
-
-~Node() {
+    /*
+~Node() noexcept(!CGAL_ASSERTIONS_ENABLED)
+{
   CGAL_NEF_TRACEN("~Node: deleting node...");
-  if( !is_leaf()) {
-    delete left_node;
-    delete right_node;
-  }
+  CGAL_destructor_assertion_catch(
+    if( !is_leaf()) {
+      delete left_node;
+      delete right_node;
+    }
+  );
 }
-
+    */
 private:
-  Node* parent_node;
-  Node* left_node;
-  Node* right_node;
+
+
+
+  Node_handle parent_node;
+  Node_handle left_node;
+  Node_handle right_node;
   Plane_3 splitting_plane;
   Point_3 point_on_plane;
   Object_list object_list;
 };
 
+  typedef boost::container::deque<Node> Node_range;
+  typedef Node* Node_handle;
 
 
 public:
@@ -468,11 +287,11 @@ public:
     class Iterator;
   protected:
     Traits traits;
-    Node *root_node;
+    Node_handle root_node;
     Segment_3 segment;
     bool initialized;
   public:
-    Objects_around_segment() : initialized(false) {}
+    Objects_around_segment() : root_node(nullptr), initialized(false) {}
     Objects_around_segment( const K3_tree& k, const Segment_3& s) :
       root_node(k.root), segment(s), initialized(true) {
       CGAL_NEF_TRACEN("Objects_around_segment: input segment: "<<segment);
@@ -495,48 +314,48 @@ public:
     {
       friend class K3_tree;
       typedef Iterator Self;
-      typedef std::pair< const Node*, Segment_3> Candidate;
+      typedef std::pair< const Node_handle, Segment_3> Candidate;
     protected:
       std::list<Candidate> S;
-      const Node* node;
+      Node_handle node;
       Traits traits;
       CGAL_assertion_code( Segment_3 prev_segment;)
       CGAL_assertion_code( bool first_segment;)
     public:
-      Iterator() : node(0) {}
-      Iterator( const Node* root, const Segment_3& s) {
+      Iterator() : node()
+      { CGAL_assertion_code( first_segment = false); }
+      Iterator( const Node_handle root, const Segment_3& s) {
         CGAL_assertion_code( first_segment = true);
         S.push_front( Candidate( root, s));
         ++(*this); // place the interator in the first intersected cell
       }
       Iterator( const Self& i) : S(i.S), node(i.node) {}
       const Object_list& operator*() const {
-        CGAL_assertion( node != 0);
+        CGAL_assertion( node != nullptr);
         return node->objects();
       }
       Self& operator++() {
 
 if( S.empty())
-  node = 0; // end of the iterator
+  node = nullptr; // end of the iterator
 else {
   while( !S.empty()) {
-    const Node* n = S.front().first;
+    Node_handle n = S.front().first;
     Segment_3 s = S.front().second;
     S.pop_front();
     if( n->is_leaf()) {
-#ifndef NDEBUG
+
       CGAL_assertion_code(
-      if( first_segment) {
-        first_segment = false;
-        CGAL_NEF_TRACEN("operator++: prev_segment=(none), segment="<<s);
-      }
-      else {
-        CGAL_assertion( prev_segment.target() == s.source());
-        CGAL_assertion( prev_segment.direction() == s.direction());
-        CGAL_NEF_TRACEN("operator++: prev_segment="<<prev_segment<<", segment="<<s);
-      }
-      prev_segment = s);
-#endif
+        if( first_segment) {
+          first_segment = false;
+          CGAL_NEF_TRACEN("operator++: prev_segment=(none), segment="<<s);
+        } else {
+          CGAL_assertion( prev_segment.target() == s.source());
+          CGAL_assertion( prev_segment.direction() == s.direction());
+          CGAL_NEF_TRACEN("operator++: prev_segment="<<prev_segment<<", segment="<<s);
+        }
+        prev_segment = s);
+
       node = n;
       break;
     }
@@ -573,13 +392,13 @@ else {
         return !(*this == i);
       }
     private:
-      const Node* get_node() const {
-        CGAL_assertion( node != 0);
+      Node_handle get_node() const {
+        CGAL_assertion( node != nullptr);
         return node;
       }
 
 inline
-const Node* get_child_by_side( const Node* node, Oriented_side side) {
+Node_handle get_child_by_side( const Node_handle node, Oriented_side side) {
   CGAL_assertion( node != nullptr);
   CGAL_assertion( side != ON_ORIENTED_BOUNDARY);
   if( side == ON_NEGATIVE_SIDE) {
@@ -644,126 +463,16 @@ void divide_segment_by_plane( Segment_3 s, Plane_3 pl,
     }
   };
 
-class Objects_around_box {
-
- public:
-  class Iterator;
- protected:
-  Node *root_node;
-  Bounding_box_3 box;
-  bool initialized;
-
- public:
-  Objects_around_box() : initialized(false) {}
-  Objects_around_box(const K3_tree& k, const Bounding_box_3& b) :
-    root_node(k.root), box(b), initialized(true) {}
-
-  void initialize( const K3_tree& k, const Bounding_box_3& b) {
-    root_node = k.root;
-    box = b;
-    initialized = true;
-  }
-
- public:
-  Iterator begin() const {
-    CGAL_assertion( initialized == true);
-    return Iterator( root_node, box);
-  }
-
-  Iterator end() const {
-    return Iterator();
-  }
-
-  class Iterator {
-
-    friend class K3_tree;
-    typedef Iterator Self;
-    typedef std::pair< const Node*, Bounding_box_3> Candidate;
-
-  protected:
-    std::list<Candidate> S;
-    const Node* node;
-
-  public:
-    Iterator() : node(0) {}
-
-    Iterator( const Node* root, const Bounding_box_3& s) {
-      S.push_front( Candidate( root, s));
-      ++(*this); // place the interator in the first intersected cell
-    }
-
-    Iterator( const Self& i) : S(i.S), node(i.node) {}
-
-    const Object_list& operator*() const {
-      CGAL_assertion( node != 0);
-      return node->objects();
-    }
-
-    Self& operator++() {
-
-      if(S.empty())
-        node = 0; // end of the iterator
-      else {
-        while( !S.empty()) {
-          const Node* n = S.front().first;
-          Bounding_box_3 b = S.front().second;
-          S.pop_front();
-          if( n->is_leaf()) {
-            node = n;
-            break;
-          } else {
-            Point_3 pmin(b.min_coord(0), b.min_coord(1), b.min_coord(2));
-            Point_3 pmax(b.max_coord(0), b.max_coord(1), b.max_coord(2));
-            Oriented_side src_side =
-              n->plane().oriented_side(pmax);
-            Oriented_side tgt_side =
-              n->plane().oriented_side(pmin);
-            if( src_side == tgt_side &&
-                src_side != ON_ORIENTED_BOUNDARY)
-              S.push_front( Candidate( get_child_by_side( n, src_side), b));
-            else {
-              S.push_front( Candidate( get_child_by_side( n, tgt_side), b));
-              S.push_front( Candidate( get_child_by_side( n, src_side), b));
-            }
-          }
-        }
-      }
-      return *this;
-    }
-
-    bool operator==(const Self& i) const {
-      return (node == i.node);
-    }
-
-    bool operator!=(const Self& i) const {
-      return !(*this == i);
-    }
-
-  private:
-    const Node* get_node() const {
-      CGAL_assertion( node != 0);
-      return node;
-    }
-
-    inline
-    const Node* get_child_by_side( const Node* node, Oriented_side side) {
-      CGAL_assertion( node != nullptr);
-      CGAL_assertion( side != ON_ORIENTED_BOUNDARY);
-      if( side == ON_NEGATIVE_SIDE) {
-        return node->left();
-      }
-      CGAL_assertion( side == ON_POSITIVE_SIDE);
-      return node->right();
-    }
-  };
-};
-
 private:
 #ifdef CGAL_NEF_EXPLOIT_REFERENCE_COUNTING
   bool reference_counted;
 #endif
   Traits traits;
-  Node* root;
+
+
+  Node_handle root;
+  boost::container::deque<Node> nodes;
+
   int max_depth;
   Bounding_box_3 bounding_box;
 public:
@@ -789,55 +498,7 @@ public:
     CGAL_forall_edges( e, *W)
       objects.push_back(make_object(Halfedge_handle(e)));
     CGAL_forall_facets( f, *W) {
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-      typedef typename SNC_structure::SHalfedge_around_facet_circulator
-                                      SHalfedge_around_facet_circulator;
-      typedef typename SNC_structure::Halffacet_cycle_iterator
-                                      Halffacet_cycle_iterator;
-
-      Halffacet_cycle_iterator fci = f->facet_cycles_begin();
-      CGAL_assertion(fci.is_shalfedge());
-      SHalfedge_around_facet_circulator safc(fci);
-      if(circulator_size(safc) > 10) {
-      typedef typename CGAL::Projection_traits_xy_3<Kernel>       XY;
-      typedef typename CGAL::Projection_traits_yz_3<Kernel>       YZ;
-      typedef typename CGAL::Projection_traits_xz_3<Kernel>       XZ;
-
-      Triangle_3 tr;
-
-      Vector_3 orth = f->plane().orthogonal_vector();
-      int c = CGAL::abs(orth[0]) > CGAL::abs(orth[1]) ? 0 : 1;
-      c = CGAL::abs(orth[2]) > CGAL::abs(orth[c]) ? 2 : c;
-
-      std::list<Triangle_3> triangles;
-      if(c == 0) {
-        Triangulation_handler<SNC_structure, YZ> th(f);
-        while(th.get_next_triangle(tr)) {
-          triangles.push_front(tr);
-          Halffacet_triangle_handle th( f, *triangles.begin());
-          objects.push_back(make_object(th));
-        }
-      } else if(c == 1) {
-        Triangulation_handler<SNC_structure, XZ> th(f);
-        while(th.get_next_triangle(tr)) {
-          triangles.push_front(tr);
-          Halffacet_triangle_handle th( f, *triangles.begin());
-          objects.push_back(make_object(th));
-        }
-      } else if(c == 2) {
-        Triangulation_handler<SNC_structure, XY> th(f);
-        while(th.get_next_triangle(tr)) {
-          triangles.push_front(tr);
-          Halffacet_triangle_handle th( f, *triangles.begin());
-          objects.push_back(make_object(th));
-        }
-      } else
-              CGAL_error_msg( "wrong value");
-      } else
-        objects.push_back(make_object(Halffacet_handle(f)));
-#else
       objects.push_back(make_object(Halffacet_handle(f)));
-#endif // CGAL_NEF3_TRIANGULATE_FACETS
     }
     Object_iterator oli=objects.begin()+v_end;
     root = build_kdtree( objects, oli, 0);
@@ -874,7 +535,6 @@ typename Object_list::difference_type n_vertices = std::distance(objects.begin()
     Unique_hash_map< Vertex_handle, bool> v_mark(false);
     Unique_hash_map< Halfedge_handle, bool> e_mark(false);
     Unique_hash_map< Halffacet_handle, bool> f_mark(false);
-    std::map< Triangle_3, bool, Compare_triangle_3<Triangle_3> > t_mark;
     for( typename Objects_around_segment::Iterator oar = objects.begin();
          oar != objects.end(); ++oar) {
       for( typename Object_list::const_iterator o = (*oar).begin();
@@ -882,12 +542,6 @@ typename Object_list::difference_type n_vertices = std::distance(objects.begin()
         Vertex_handle v;
         Halfedge_handle e;
         Halffacet_handle f;
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-        Halffacet_triangle_handle t;
-#endif
-#ifdef CGAL_NEF3_FACET_WITH_BOX
-        Partial_facet pf;
-#endif
         if( CGAL::assign( v, *o)) {
           if( !v_mark[v]) {
             O.push_back(*o);
@@ -906,20 +560,6 @@ typename Object_list::difference_type n_vertices = std::distance(objects.begin()
             f_mark[f] = true;
           }
         }
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-        else if(CGAL::assign(t, *o)) {
-          Triangle_3 tr = t.get_triangle();
-          if( !t_mark[tr]) {
-            O.push_back(*o);
-            t_mark[tr] = true;
-          }
-        }
-#endif
-#ifdef CGAL_NEF3_FACET_WITH_BOX
-        else if(CGAL::assign(pf, *o)) {
-          CGAL_error_msg( "wrong type");
-        }
-#endif
         else
           CGAL_error_msg( "wrong handle");
       }
@@ -949,8 +589,8 @@ typename Object_list::difference_type n_vertices = std::distance(objects.begin()
   public:
     BBox_updater() {}
 
-    void pre_visit(const Node*) {}
-    void post_visit(const Node* n) {
+    void pre_visit(const Node_handle) {}
+    void post_visit(const Node_handle n) {
       typename Object_list::const_iterator o;
       for( o = n->objects().begin();
            o != n->objects().end(); ++o) {
@@ -967,22 +607,20 @@ typename Object_list::difference_type n_vertices = std::distance(objects.begin()
   };
 
   template <typename Visitor>
-  void visit_k3tree(const Node* current, Visitor& V) const {
+  void visit_k3tree(const Node_handle current, Visitor& V) const {
     V.pre_visit(current);
-    if(current->left() != 0) {
+    if(current->left() != nullptr) {
       visit_k3tree(current->left(), V);
       visit_k3tree(current->right(), V);
     }
     V.post_visit(current);
   }
 
-  size_t bytes() { return root->bytes();}
-  size_t leafs(int mask = 255, int lower_limit=0) { return root->leafs(mask, lower_limit);}
-
   void transform(const Aff_transformation_3& t) {
-    // TODO: Bounding box must be updated/transformed, too
-    if(root != 0)
-      root->transform(t);
+    if(root == nullptr){
+      return;
+    }
+    root->transform(t);
 
     BBox_updater bbup;
     visit_k3tree(root, bbup);
@@ -994,7 +632,7 @@ typename Object_list::difference_type n_vertices = std::distance(objects.begin()
 template <typename T>
 friend std::ostream& operator<<
 (std::ostream& os, const K3_tree<T>& k3_tree) {
-  os << (const Node*)k3_tree.root; // no default conversion to const Node*?
+  os << (const Node_handle)k3_tree.root; // no default conversion to const Node_handle?
   return os;
 }
 #endif
@@ -1005,14 +643,6 @@ std::string dump_object_list( const Object_list& O, int level = 0) {
   Vertex_handle v;
   Halfedge_handle e;
   Halffacet_handle f;
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-  typename Object_list::size_type t_count = 0;
-  Halffacet_triangle_handle t;
-#endif
-#ifdef CGAL_NEF3_FACET_WITH_BOX
-  typename Object_list::size_type p_count = 0;
-  Partial_facet pf;
-#endif
   for( o = O.begin(); o != O.end(); ++o) {
     if( CGAL::assign( v, *o)) {
       if( level) os << v->point() << std::endl;
@@ -1027,99 +657,34 @@ std::string dump_object_list( const Object_list& O, int level = 0) {
       if( level) os << "facet" << std::endl;
       ++f_count;
     }
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-    else if( CGAL::assign(t, *o)) {
-      if( level) os << "triangle" << std::endl;
-      ++t_count;
-    }
-#endif
-#ifdef CGAL_NEF3_FACET_WITH_BOX
-    else if( CGAL::assign(pf, *o)) {
-      if( level) pf.debug();
-      ++p_count;
-    }
-#endif
     else
       CGAL_error_msg( "wrong handle");
   }
   os << v_count << "v " << e_count << "e " << f_count << "f ";
-#ifdef CGAL_NEF3_TRIANGULATE_FACETS
-  os  << t_count << "t ";
-#endif
-#ifdef CGAL_NEF3_FACET_WITH_BOX
-  os  << p_count << "p ";
-#endif
   return os.str();
  }
 
-bool update( Unique_hash_map<Vertex_handle, bool>& V,
-             Unique_hash_map<Halfedge_handle, bool>& E,
-             Unique_hash_map<Halffacet_handle, bool>& F) {
-  return update( root, V, E, F);
-}
-
-bool update( Node* node,
-             Unique_hash_map<Vertex_handle, bool>& V,
-             Unique_hash_map<Halfedge_handle, bool>& E,
-             Unique_hash_map<Halffacet_handle, bool>& F) {
-  CGAL_assertion( node != 0);
-  if( node->is_leaf()) {
-    bool updated = false;
-    Object_list* O = &node->object_list;
-    typename Object_list::iterator onext, o = O->begin();
-    while( o != O->end()) {
-      onext = o;
-      onext++;
-      Vertex_handle v;
-      Halfedge_handle e;
-      Halffacet_handle f;
-      if( CGAL::assign( v, *o)) {
-        if( !V[v]) {
-          O->erase(o);
-          updated = true;
-        }
-      }
-      else if( CGAL::assign( e, *o)) {
-        if( !E[e]) {
-          O->erase(o);
-          updated = true;
-        }
-      }
-      else if( CGAL::assign( f, *o)) {
-        if( !F[f]) {
-          O->erase(o);
-          updated = true;
-        }
-      }
-      else CGAL_error_msg( "wrong handle");
-      o = onext;
-    }
-    return updated;
-  }
-  // TODO: protect the code below from optimizations!
-  bool left_updated = update( node->left_node, V, E, F);
-  CGAL_NEF_TRACEN("k3_tree::update(): left node updated? "<<left_updated);
-  bool right_updated = update( node->right_node, V, E, F);
-  CGAL_NEF_TRACEN("k3_tree::update(): right node updated? "<<right_updated);
-  return (left_updated || right_updated);
-}
-
-~K3_tree() {
+  /*
+~K3_tree() noexcept(!CGAL_ASSERTIONS_ENABLED)
+{
   CGAL_NEF_TRACEN("~K3_tree: deleting root...");
-  delete root;
+  CGAL_destructor_assertion_catch(
+    delete root;
+  );
 }
-
+  */
 private:
 
 template <typename Depth>
-Node* build_kdtree(Object_list& O, Object_iterator v_end,
-                   Depth depth, Node* parent=0, int non_efective_splits=0) {
+Node_handle build_kdtree(Object_list& O, Object_iterator v_end,
+                   Depth depth, Node_handle parent=nullptr, int non_efective_splits=0) {
   CGAL_precondition( depth >= 0);
   CGAL_NEF_TRACEN( "build_kdtree: "<<O.size()<<" objects, "<<"depth "<<depth);
   CGAL_NEF_TRACEN( "build_kdtree: "<<dump_object_list(O,1));
   if( !can_set_be_divided(O.begin(), v_end, depth)) {
     CGAL_NEF_TRACEN("build_kdtree: set cannot be divided");
-    return new Node( parent, 0, 0, Plane_3(), O);
+    nodes.push_back(Node( parent, nullptr, nullptr, Plane_3(), O));
+    return &(nodes.back());
   }
   Object_iterator median;
   Plane_3 partition_plane = construct_splitting_plane(O.begin(), v_end, median, depth);
@@ -1161,7 +726,8 @@ Node* build_kdtree(Object_list& O, Object_iterator v_end,
   if( !splitted) {
     CGAL_NEF_TRACEN("build_kdtree: splitting plane not found");
     //    if(depth > max_depth)
-    return new Node( parent, 0, 0, Plane_3(), O);
+    nodes.push_back(Node( parent, nullptr, nullptr, Plane_3(), O));
+    return &(nodes.back());
   } else {
     CGAL_NEF_TRACEN("Sizes " << O1.size() << ", " << O2.size() << ", " << O.size());
     CGAL_assertion( O1.size() <= O.size() && O2.size() <= O.size());
@@ -1174,9 +740,11 @@ Node* build_kdtree(Object_list& O, Object_iterator v_end,
     non_efective_splits = 0;
   if( non_efective_splits > 2) {
     CGAL_NEF_TRACEN("build_kdtree: non efective splits reached maximum");
-    return new Node( parent, 0, 0, Plane_3(), O);
+    nodes.push_back(Node( parent, nullptr, nullptr, Plane_3(), O));
+    return &(nodes.back());
   }
-  Node *node = new Node( parent, 0, 0, partition_plane, Object_list());
+  nodes.push_back(Node( parent, nullptr, nullptr, partition_plane, Object_list()));
+  Node_handle node = &(nodes.back());
   node->left_node = build_kdtree( O1, O1.begin()+v_end1, depth + 1, node, non_efective_splits);
   node->right_node = build_kdtree( O2, O2.begin()+v_end2, depth + 1, node, non_efective_splits);
   return node;
@@ -1201,19 +769,6 @@ bool classify_objects(Object_iterator start, Object_iterator end,
   Point_3 point_on_plane(partition_plane.point());
 
   for( o = start; o != end; ++o) {
-#ifdef CGAL_NEF3_FACET_WITH_BOX
-    Partial_facet pf;
-    if(CGAL::assign(pf, *o)) {
-      Partial_facet pfn,pfp;
-      if(pf.divide(partition_plane, pfn, pfp)) {
-        *o1 = make_object(pfn);
-        ++o1;
-        *o2 = make_object(pfp);
-        ++o2;
-        continue;
-      }
-    }
-#endif
     Oriented_side side = sop( point_on_plane, *o, depth);
     if( side == ON_NEGATIVE_SIDE || side == ON_ORIENTED_BOUNDARY) {
       *o1 = *o;
@@ -1253,8 +808,8 @@ Plane_3 construct_splitting_plane(Object_iterator start, Object_iterator end,
   return Plane_3();
 }
 
-const Node *locate_cell_containing( const Point_3& p, const Node* node) const {
-  CGAL_precondition( node != 0);
+Node_handle locate_cell_containing( const Point_3& p, const Node_handle node) const {
+  CGAL_precondition( node != nullptr);
   if( node->is_leaf())
     return node;
   else {
@@ -1268,13 +823,13 @@ const Node *locate_cell_containing( const Point_3& p, const Node* node) const {
   }
 }
 
-const Object_list& locate( const Point_3& p, const Node* node) const {
-  CGAL_precondition( node != 0);
+const Object_list& locate( const Point_3& p, const Node_handle node) const {
+  CGAL_precondition( node != nullptr);
   return locate_cell_containing( p, node)->objects();
 }
 
-bool is_point_on_cell( const Point_3& p, const Node* target, const Node* current) const {
-  CGAL_precondition( target != 0 && current != 0);
+bool is_point_on_cell( const Point_3& p, const Node_handle target, const Node_handle current) const {
+  CGAL_precondition( target != nullptr && current != nullptr);
   if( current->is_leaf())
     return (current == target);
   Oriented_side side = current->plane().oriented_side(p);
