@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Nef_3/include/CGAL/Nef_3/polygon_mesh_to_nef_3.h $
-// $Id: polygon_mesh_to_nef_3.h adb0b9d 2020-04-19T14:27:48+02:00 R.E. Wolff
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Nef_3/include/CGAL/Nef_3/polygon_mesh_to_nef_3.h $
+// $Id: polygon_mesh_to_nef_3.h 45800d2 2021-03-24T15:05:22+01:00 Laurent Rineau
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -112,7 +112,7 @@ class Face_graph_index_adder {
   typedef typename boost::graph_traits<Polyhedron>::halfedge_descriptor halfedge_descriptor;
  public:
   Face_graph_index_adder(Polyhedron&, HalfedgeIndexMap ) {}
-  void set_hash(halfedge_descriptor,
+  void set_edge(halfedge_descriptor,
                 SHalfedge_handle) {}
   void resolve_indexes() {}
 };
@@ -126,21 +126,21 @@ class Face_graph_index_adder<CGAL::SNC_indexed_items, PolygonMesh, SNC_structure
 
   typedef Halfedge_around_face_circulator<PolygonMesh>
     Halfedge_around_facet_const_circulator;
-    typedef std::vector<SHalfedge_handle> Hash;
+  typedef std::vector<SHalfedge_handle> SHalfedges;
 
   PolygonMesh& P;
   HalfedgeIndexMap him;
-  Hash hash;
+  SHalfedges shalfedges;
 
 public:
   Face_graph_index_adder(PolygonMesh& P_, HalfedgeIndexMap him) : P(P_), him(him)
   {
-    hash.resize(num_halfedges(P));
+    shalfedges.resize(num_halfedges(P));
   }
 
-  void set_hash(halfedge_descriptor evc,
+  void set_edge(halfedge_descriptor evc,
                 SHalfedge_handle se) {
-    hash[get(him,evc)] = se;
+    shalfedges[get(him,evc)] = se;
   }
 
   void resolve_indexes()
@@ -148,26 +148,22 @@ public:
     for(face_descriptor fi : faces(P)) {
       Halfedge_around_facet_const_circulator
         fc(halfedge(fi,P),P), end(fc);
-      typename boost::property_traits<HalfedgeIndexMap>::value_type
-        index = get(him,*fc);
-      hash[index]->set_index();
-      hash[index]->twin()->set_index();
-      hash[index]->twin()->source()->set_index();
-      int se  = hash[index]->get_index();
-      int set = hash[index]->twin()->get_index();
-      int sv  = hash[index]->twin()->source()->get_index();
+      SHalfedge_handle s = shalfedges[get(him,*fc)];
+      int se  = s->new_index();
+      int set = s->twin()->new_index();
+      int sv  = s->twin()->source()->new_index();
 
       ++fc;
       CGAL_For_all(fc, end) {
-        index = get(him,*fc);
-        hash[index]->set_index(se);
-        hash[index]->twin()->set_index(set);
-        hash[index]->source()->set_index(sv);
-        hash[index]->twin()->source()->set_index();
-        sv = hash[index]->twin()->source()->get_index();
+        SHalfedge_handle n = shalfedges[get(him,*fc)];
+        n->set_index(se);
+        n->twin()->set_index(set);
+        n->source()->set_index(sv);
+        sv = n->twin()->source()->new_index();
       }
-      hash[get(him,*fc)]->source()->set_index(sv);
+      s->source()->set_index(sv);
     }
+
   }
 };
 
@@ -192,16 +188,18 @@ void polygon_mesh_to_nef_3(PolygonMesh& P, SNC_structure& S, FaceIndexMap fimap,
   typedef Halfedge_around_target_circulator<PolygonMesh>
                                Halfedge_around_vertex_const_circulator;
 
-
   PMap pmap = get(CGAL::vertex_point,P);
 
   std::vector<Vector_3> normals(num_faces(P));
+  CGAL_assertion_code(std::vector<std::size_t>  num_edges(num_faces(P));)
 
   for(face_descriptor f : faces(P)){
     Vertex_around_face_circulator<PolygonMesh> vafc(halfedge(f,P),P), done(vafc);
     Vector_3 v;
     normal_vector_newell_3(vafc, done, pmap, v);
-    normals[get(fimap,f)] = - v;
+    std::size_t i = get(fimap,f);
+    normals[i] = -v;
+    CGAL_assertion_code(num_edges[i] = circulator_size(vafc));
   }
 
   Face_graph_index_adder<typename SNC_structure::Items,
@@ -209,10 +207,12 @@ void polygon_mesh_to_nef_3(PolygonMesh& P, SNC_structure& S, FaceIndexMap fimap,
 
 
   for(vertex_descriptor pv : vertices(P) ) {
+
+    typename boost::property_traits<PMap>::reference npv = get(pmap,pv);
     Vertex_handle nv = S.new_vertex();
-    nv->point() = get(pmap,pv);
+    nv->point() = npv;
     nv->mark() = true;
-    CGAL_NEF_TRACEN("v "<< get(pmap,pv));
+    CGAL_NEF_TRACEN("v "<< npv);
 
     SM_decorator SM(&*nv);
     Halfedge_around_vertex_const_circulator pec(pv,P), pec_prev(pec), done(pec);
@@ -221,7 +221,7 @@ void polygon_mesh_to_nef_3(PolygonMesh& P, SNC_structure& S, FaceIndexMap fimap,
     // CGAL_assertion( pe != 0 );
 
     Point_3 pe_target_0(get(pmap,target(opposite(pe,P),P)));
-    Point_3 sp_point_0(CGAL::ORIGIN+(pe_target_0 - get(pmap,pv)));
+    Point_3 sp_point_0(CGAL::ORIGIN+(pe_target_0 - npv));
     Sphere_point sp_0(sp_point_0);
     SVertex_handle sv_0 = SM.new_svertex(sp_0);
     sv_0->mark() = true;
@@ -234,11 +234,11 @@ void polygon_mesh_to_nef_3(PolygonMesh& P, SNC_structure& S, FaceIndexMap fimap,
     bool with_border = false;
     do {
       CGAL_assertion(face(pe_prev,P) == face(opposite(pe,P),P));
-      CGAL_assertion(get(pmap,target(pe_prev,P)) == get(pmap,pv));
-      CGAL_assertion(get(pmap,target(pe,P)) == get(pmap,pv));
+      CGAL_assertion(get(pmap,target(pe_prev,P)) == npv);
+      CGAL_assertion(get(pmap,target(pe,P)) == npv);
 
       Point_3 pe_target = get(pmap,target(opposite(pe,P),P));
-      Point_3 sp_point = CGAL::ORIGIN+(pe_target - get(pmap,pv));
+      Point_3 sp_point = CGAL::ORIGIN+(pe_target - npv);
       Sphere_point sp(sp_point);
       SVertex_handle sv = SM.new_svertex(sp);
       sv->mark() = true;
@@ -249,18 +249,20 @@ void polygon_mesh_to_nef_3(PolygonMesh& P, SNC_structure& S, FaceIndexMap fimap,
       if(is_border(pe_prev,P))
         with_border = true;
       else {
-  Plane ss_plane( CGAL::ORIGIN, normals[get(fimap,face(pe_prev,P))] );
+        std::size_t i = get(fimap,face(pe_prev,P));
+        Plane ss_plane( CGAL::ORIGIN, normals[i]);
         Sphere_circle ss_circle(ss_plane);
-
-  CGAL_assertion(ss_circle.has_on(sp));
-  CGAL_assertion(ss_circle.has_on(sv_prev->point()));
+        CGAL_assertion_code(if(num_edges[i] > 3) {
+          CGAL_assertion(ss_circle.has_on(sp));
+          CGAL_assertion(ss_circle.has_on(sv_prev->point()));
+        };)
 
         SHalfedge_handle e = SM.new_shalfedge_pair(sv_prev, sv);
         e->circle() = ss_circle;
         e->twin()->circle() = ss_circle.opposite();
         e->mark() = e->twin()->mark() = true;
 
-        index_adder.set_hash(pe_prev, e);
+        index_adder.set_edge(pe_prev, e);
       }
 
       sv_prev = sv;
@@ -272,27 +274,29 @@ void polygon_mesh_to_nef_3(PolygonMesh& P, SNC_structure& S, FaceIndexMap fimap,
     while( pec != done );
 
     CGAL_assertion(face(pe_prev,P) == face(opposite(*pe_0,P),P));
-    CGAL_assertion(get(pmap,target(pe_prev,P)) == get(pmap,pv));
-    CGAL_assertion(get(pmap,target(*pe_0,P)) == get(pmap,pv));
+    CGAL_assertion(get(pmap,target(pe_prev,P)) == npv);
+    CGAL_assertion(get(pmap,target(*pe_0,P)) == npv);
 
     SHalfedge_handle e;
     if(is_border(pe_prev,P)) {
       with_border = true;
       e = sv_prev->out_sedge();
     } else {
-      Plane ss_plane( CGAL::ORIGIN, normals[get(fimap,face(pe_prev,P))] );
+      std::size_t i = get(fimap,face(pe_prev,P));
+      Plane ss_plane( CGAL::ORIGIN, normals[i]);
       Sphere_circle ss_circle(ss_plane);
 
-      CGAL_assertion(ss_plane.has_on(sv_prev->point()));
-      CGAL_assertion(ss_circle.has_on(sp_0));
-      CGAL_assertion(ss_circle.has_on(sv_prev->point()));
+      CGAL_assertion_code(if(num_edges[i] > 3) {
+        CGAL_assertion(ss_circle.has_on(sp_0));
+        CGAL_assertion(ss_circle.has_on(sv_prev->point()));
+      };)
 
       e = SM.new_shalfedge_pair(sv_prev, sv_0);
       e->circle() = ss_circle;
       e->twin()->circle() = ss_circle.opposite();
       e->mark() = e->twin()->mark() = true;
 
-      index_adder.set_hash(pe_prev, e);
+      index_adder.set_edge(pe_prev, e);
     }
 
     // create faces
