@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/detect_features.h $
-// $Id: detect_features.h c253679 2020-04-18T16:27:58+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/detect_features.h $
+// $Id: detect_features.h 590ddf8 2021-10-08T15:38:47+02:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,15 +16,13 @@
 
 #include <CGAL/license/Polygon_mesh_processing/detect_features.h>
 
-#include <CGAL/disable_warnings.h>
-
 #include <CGAL/Kernel/global_functions_3.h>
 #include <CGAL/Polygon_mesh_processing/compute_normal.h>
 #include <CGAL/Polygon_mesh_processing/internal/named_params_helper.h>
 #include <CGAL/boost/graph/properties.h>
 #include <CGAL/Polygon_mesh_processing/connected_components.h>
-#include <set>
 
+#include <set>
 
 namespace CGAL {
 namespace Polygon_mesh_processing {
@@ -45,35 +43,50 @@ generate_patch_id(std::pair<Int, Int>, int i)
   return std::pair<Int, Int>(i, 0);
 }
 
-template <typename PolygonMesh, typename GT>
+template <typename PolygonMesh, typename VPM, typename GT>
 bool
-is_sharp(PolygonMesh& polygonMesh,
-         const typename boost::graph_traits<PolygonMesh>::halfedge_descriptor& he,
-         const typename GT::FT& cos_angle)
+is_sharp(const typename boost::graph_traits<PolygonMesh>::halfedge_descriptor h,
+         const PolygonMesh& pmesh,
+         const VPM vpm,
+         const GT gt,
+         const typename GT::Sign cos_sign,
+         const typename GT::FT sq_cos_angle)
 {
-  typedef typename boost::graph_traits<PolygonMesh>::face_descriptor face_descriptor;
-  if(is_border(edge(he,polygonMesh),polygonMesh)){
+  typedef typename GT::FT                                                      FT;
+  typedef typename GT::Vector_3                                                Vector_3;
+
+  typedef typename boost::graph_traits<PolygonMesh>::halfedge_descriptor       halfedge_descriptor;
+
+  if(is_border_edge(h, pmesh))
     return false;
-  }
-  face_descriptor f1 = face(he,polygonMesh);
-  face_descriptor f2 = face(opposite(he,polygonMesh),polygonMesh);
 
-  const typename GT::Vector_3& n1 = Polygon_mesh_processing::compute_face_normal(f1,polygonMesh);
-  const typename GT::Vector_3& n2 = Polygon_mesh_processing::compute_face_normal(f2,polygonMesh);
+  typename GT::Construct_vector_3 vector = gt.construct_vector_3_object();
+  typename GT::Construct_cross_product_vector_3 cross = gt.construct_cross_product_vector_3_object();
+  typename GT::Compute_squared_length_3 sq_length = gt.compute_squared_length_3_object();
 
-  if ( n1 * n2 <= cos_angle )
-    return true;
+  halfedge_descriptor opp_h = opposite(h, pmesh);
+
+  const Vector_3 vc = vector(get(vpm, source(h, pmesh)), get(vpm, target(h, pmesh)));
+  const Vector_3 v1 = vector(get(vpm, source(h, pmesh)), get(vpm, target(next(h, pmesh), pmesh)));
+  const Vector_3 v2 = vector(get(vpm, target(next(opp_h, pmesh), pmesh)), get(vpm, target(opp_h, pmesh)));
+
+  const Vector_3 n1 = cross(vc, v1);
+  const Vector_3 n2 = cross(vc, v2);
+  const FT sp = n1 * n2;
+
+  // n1.n2 <= cos() without computing the norms of the vectors
+  if(cos_sign == NEGATIVE)
+    return (is_negative(sp) && (square(sp) >= sq_cos_angle * sq_length(n1) * sq_length(n2)));
   else
-    return false;
+    return (is_negative(sp) || (square(sp) <= sq_cos_angle * sq_length(n1) * sq_length(n2)));
 }
 
-
 //wrapper for patchid map.
 template<typename PatchIdMap,
          typename ValueType = typename boost::property_traits<PatchIdMap>::value_type>
 struct PatchIdMapWrapper
 {
-  typedef typename boost::property_traits<PatchIdMap>::category category;
+  typedef typename boost::read_write_property_map_tag category;
   typedef ValueType value_type;
   typedef typename boost::property_traits<PatchIdMap>::reference reference;
   typedef typename boost::property_traits<PatchIdMap>::key_type key_type;
@@ -105,7 +118,7 @@ void put(PatchIdMapWrapper<PatchIdMap, Int>& map, Handle_type h,
 template<typename PatchIdMap, typename Int>
 struct PatchIdMapWrapper<PatchIdMap, std::pair<Int, Int> >
 {
-  typedef typename boost::property_traits<PatchIdMap>::category category;
+  typedef typename boost::read_write_property_map_tag category;
   typedef Int value_type;
   typedef typename boost::property_traits<PatchIdMap>::reference reference;
   typedef typename boost::property_traits<PatchIdMap>::key_type key_type;
@@ -133,7 +146,7 @@ void put(PatchIdMapWrapper<PatchIdMap, std::pair<Int, Int> >& map, Handle_type h
 template <typename PolygonMesh, typename PatchIdMap,
           typename EdgeIsFeatureMap, typename NamedParameters>
 typename boost::graph_traits<PolygonMesh>::faces_size_type
-detect_surface_patches(PolygonMesh& p,
+detect_surface_patches(const PolygonMesh& p,
                        PatchIdMap patch_id_map,
                        EdgeIsFeatureMap eif,
                        const NamedParameters& np)
@@ -152,7 +165,7 @@ detect_surface_patches(PolygonMesh& p,
 
 template <typename PolygonMesh, typename EdgeIsFeatureMap, typename PatchIdMap>
 typename boost::graph_traits<PolygonMesh>::faces_size_type
-detect_surface_patches(PolygonMesh& p,
+detect_surface_patches(const PolygonMesh& p,
                        PatchIdMap patch_id_map,
                        EdgeIsFeatureMap eif)
 {
@@ -160,69 +173,64 @@ detect_surface_patches(PolygonMesh& p,
 }
 
 
-template<typename GT,
-         typename FT,
-         typename PolygonMesh,
-         typename EIFMap,
-         typename VNFEMap>
- void sharp_call(PolygonMesh& pmesh,
-                 FT angle_in_deg,
-                 EIFMap edge_is_feature_map,
-                 VNFEMap vnfe)
+template <typename FT, typename PolygonMesh, typename VPM, typename GT, typename EIFMap, typename VNFEMap>
+void sharp_call(const FT angle_in_deg,
+                const PolygonMesh& pmesh,
+                const VPM vpm,
+                const GT gt,
+                EIFMap edge_is_feature_map,
+                VNFEMap vnfe)
 {
   // Initialize vertices
-  for(typename boost::graph_traits<PolygonMesh>::vertex_descriptor vd :
-                vertices(pmesh))
-  {
+  for(typename boost::graph_traits<PolygonMesh>::vertex_descriptor vd : vertices(pmesh))
     put(vnfe, vd, 0);
-  }
-  FT cos_angle ( std::cos(CGAL::to_double(angle_in_deg) * CGAL_PI / 180.) );
+
+  const FT cos_angle = std::cos(CGAL::to_double(angle_in_deg) * CGAL_PI / 180.);
+  const FT sq_cos_angle = square(cos_angle);
 
   // Detect sharp edges
   for(typename boost::graph_traits<PolygonMesh>::edge_descriptor ed : edges(pmesh))
   {
-    typename boost::graph_traits<PolygonMesh>::halfedge_descriptor he = halfedge(ed,pmesh);
-    if(is_border_edge(he,pmesh)
-      || angle_in_deg == FT()
-      || (angle_in_deg != FT(180) && internal::is_sharp<PolygonMesh, GT>(pmesh,he,cos_angle))
-      )
+    typename boost::graph_traits<PolygonMesh>::halfedge_descriptor he = halfedge(ed, pmesh);
+    if(is_border_edge(he, pmesh) ||
+       angle_in_deg == FT() ||
+       (angle_in_deg != FT(180) && internal::is_sharp(he, pmesh, vpm, gt, CGAL::sign(cos_angle), sq_cos_angle)))
     {
       put(edge_is_feature_map, edge(he, pmesh), true);
-      put(vnfe, target(he,pmesh), get(vnfe, target(he,pmesh))+1);
-      put(vnfe, source(he,pmesh), get(vnfe, source(he,pmesh))+1);
+      put(vnfe, target(he, pmesh), get(vnfe, target(he, pmesh))+1);
+      put(vnfe, source(he, pmesh), get(vnfe, source(he, pmesh))+1);
     }
   }
 }
 
-
-template<typename GT,
-         typename FT,
-         typename PolygonMesh,
-         typename EIFMap>
- void sharp_call(PolygonMesh& pmesh,
-                 FT& angle_in_deg,
-                 EIFMap edge_is_feature_map,
-                 const internal_np::Param_not_found&)
+template <typename FT, typename PolygonMesh, typename VPM, typename GT, typename EIFMap>
+void sharp_call(const FT angle_in_deg,
+                const PolygonMesh& pmesh,
+                const VPM vpm,
+                const GT gt,
+                EIFMap edge_is_feature_map,
+                const internal_np::Param_not_found&)
 {
   typedef typename boost::graph_traits<PolygonMesh>::edge_descriptor     edge_descriptor;
   typedef typename boost::graph_traits<PolygonMesh>::halfedge_descriptor halfedge_descriptor;
 
-  FT cos_angle ( std::cos(CGAL::to_double(angle_in_deg) * CGAL_PI / 180.) );
+  const FT cos_angle = std::cos(CGAL::to_double(angle_in_deg) * CGAL_PI / 180.);
+  const FT sq_cos_angle = square(cos_angle);
 
   // Detect sharp edges
   for(edge_descriptor ed : edges(pmesh))
   {
-    halfedge_descriptor he = halfedge(ed,pmesh);
-    if(is_border_edge(he,pmesh)
-      || angle_in_deg == FT()
-      || (angle_in_deg != FT(180) && internal::is_sharp<PolygonMesh, GT>(pmesh,he,cos_angle))
-      )
+    halfedge_descriptor he = halfedge(ed, pmesh);
+    if(is_border_edge(he, pmesh) ||
+       angle_in_deg == FT() ||
+       (angle_in_deg != FT(180) && internal::is_sharp(he, pmesh, vpm, gt, CGAL::sign(cos_angle), sq_cos_angle)))
     {
       put(edge_is_feature_map, edge(he, pmesh), true);
     }
   }
 }
-} //end internal
+
+} // namespace internal
 
 /*!
  * \ingroup PMP_detect_features_grp
@@ -270,24 +278,30 @@ template <typename PolygonMesh, typename FT,
 #else
 template <typename PolygonMesh, typename EdgeIsFeatureMap, typename NamedParameters>
 #endif
-void detect_sharp_edges(PolygonMesh& pmesh,
+void detect_sharp_edges(const PolygonMesh& pmesh,
 #ifdef DOXYGEN_RUNNING
-    FT angle_in_deg,
+                        FT angle_in_deg,
 #else
-    typename GetGeomTraits<PolygonMesh, NamedParameters>::type::FT angle_in_deg,
+                        typename GetGeomTraits<PolygonMesh, NamedParameters>::type::FT angle_in_deg,
 #endif
-    EdgeIsFeatureMap edge_is_feature_map,
-    const NamedParameters& np)
+                        EdgeIsFeatureMap edge_is_feature_map,
+                        const NamedParameters& np)
 {
-  //extract types from NPs
+  using parameters::choose_parameter;
+  using parameters::get_parameter;
+
+  // extract types from NPs
   typedef typename GetGeomTraits<PolygonMesh, NamedParameters>::type GT;
-  typedef typename GT::FT          FT;
+  GT gt = choose_parameter<GT>(get_parameter(np, internal_np::geom_traits));
 
-  internal::sharp_call<GT, FT>(pmesh, angle_in_deg, edge_is_feature_map,
-                               parameters::get_parameter(np, internal_np::vertex_feature_degree));
+  typedef typename GetVertexPointMap<PolygonMesh, NamedParameters>::const_type VPM;
+  VPM vpm = choose_parameter(get_parameter(np, internal_np::vertex_point),
+                             get_const_property_map(boost::vertex_point, pmesh));
+
+  internal::sharp_call(angle_in_deg, pmesh, vpm, gt, edge_is_feature_map,
+                       get_parameter(np, internal_np::vertex_feature_degree));
 }
 
-
 /*!
  * \ingroup PMP_detect_features_grp
  *
@@ -315,7 +329,7 @@ void detect_sharp_edges(PolygonMesh& pmesh,
 
 template <typename PolygonMesh, typename PatchIdMap,
           typename VertexIncidentPatchesMap, typename EdgeIsFeatureMap>
-void detect_vertex_incident_patches(PolygonMesh& pmesh,
+void detect_vertex_incident_patches(const PolygonMesh& pmesh,
                              const PatchIdMap patch_id_map,
                              VertexIncidentPatchesMap vertex_incident_patches_map,
                              const EdgeIsFeatureMap edge_is_feature_map)
@@ -326,19 +340,18 @@ void detect_vertex_incident_patches(PolygonMesh& pmesh,
   for(vertex_descriptor vit :vertices(pmesh))
   {
     // Look only at feature vertices
-    if( ! get(edge_is_feature_map, edge(halfedge(vit, pmesh), pmesh) ))
-    { continue; }
+    if(!get(edge_is_feature_map, edge(halfedge(vit, pmesh), pmesh)))
+      continue;
 
     // Loop on incident facets of vit
-    typename VertexIncidentPatchesMap::value_type&
-      id_set = vertex_incident_patches_map[vit];
-    for(halfedge_descriptor he : halfedges_around_target(vit,pmesh))
+    typename VertexIncidentPatchesMap::value_type& id_set = vertex_incident_patches_map[vit];
+    for(halfedge_descriptor he : halfedges_around_target(vit, pmesh))
     {
-      if( ! is_border(he,pmesh) )
+      if(!is_border(he, pmesh))
       {
         id_set.insert(get(patch_id_map, face(he, pmesh)));
       }
-      else if( ! is_border(opposite(he,pmesh),pmesh) )
+      else if(!is_border(opposite(he, pmesh), pmesh))
       {
         id_set.insert(get(patch_id_map, face(opposite(he, pmesh), pmesh)));
       }
@@ -346,26 +359,22 @@ void detect_vertex_incident_patches(PolygonMesh& pmesh,
   }
 }
 
+namespace internal {
 
-namespace internal
+template<typename PolygonMesh, typename PIDMap, typename VIPMap, typename EIFMap>
+void vip_call(const PolygonMesh& mesh, PIDMap pid, VIPMap vip, EIFMap eif)
 {
-  template<typename PolygonMesh,
-              typename PIDMap,
-              typename VIPMap,
-              typename EIFMap>
-  void vip_call(PolygonMesh& mesh, PIDMap pid, VIPMap vip, EIFMap eif )
-  {
-    CGAL::Polygon_mesh_processing::detect_vertex_incident_patches(mesh, pid, vip, eif);
-  }
+  CGAL::Polygon_mesh_processing::detect_vertex_incident_patches(mesh, pid, vip, eif);
+}
+
+template<typename PolygonMesh, typename PIDMap, typename EIFMap>
+void vip_call(const PolygonMesh&, PIDMap, const internal_np::Param_not_found&, EIFMap)
+{
+  //do nothing when the parameter is not given
+}
+
+} // namespace internal
 
-  template<typename PolygonMesh,
-           typename PIDMap,
-           typename EIFMap>
-  void vip_call(PolygonMesh&, PIDMap, const internal_np::Param_not_found&, EIFMap)
-  {
-    //do nothing when the parameter is not given
-  }
-}//end internal
 /*!
  * \ingroup PMP_detect_features_grp
  *
@@ -446,30 +455,30 @@ template <typename PolygonMesh,
           typename EdgeIsFeatureMap, typename PatchIdMap, typename NamedParameters>
 #endif
 typename boost::graph_traits<PolygonMesh>::faces_size_type
-sharp_edges_segmentation(PolygonMesh& pmesh,
+sharp_edges_segmentation(const PolygonMesh& pmesh,
 #ifdef DOXYGEN_RUNNING
-      FT angle_in_deg,
+                         FT angle_in_deg,
 #else
-      typename GetGeomTraits<PolygonMesh, NamedParameters>::type::FT angle_in_deg,
+                         typename GetGeomTraits<PolygonMesh, NamedParameters>::type::FT angle_in_deg,
 #endif
-      EdgeIsFeatureMap edge_is_feature_map,
-      PatchIdMap patch_id_map,
-      const NamedParameters& np)
+                         EdgeIsFeatureMap edge_is_feature_map,
+                         PatchIdMap patch_id_map,
+                         const NamedParameters& np)
 {
-    detect_sharp_edges(pmesh, angle_in_deg, edge_is_feature_map, np);
+  detect_sharp_edges(pmesh, angle_in_deg, edge_is_feature_map, np);
 
-    typename boost::graph_traits<PolygonMesh>::faces_size_type result =
-      internal::detect_surface_patches(pmesh, patch_id_map, edge_is_feature_map, np);
+  typename boost::graph_traits<PolygonMesh>::faces_size_type result =
+    internal::detect_surface_patches(pmesh, patch_id_map, edge_is_feature_map, np);
 
-    internal::vip_call(pmesh, patch_id_map,
-      parameters::get_parameter(np, internal_np::vertex_incident_patches), edge_is_feature_map);
+  internal::vip_call(pmesh, patch_id_map,
+    parameters::get_parameter(np, internal_np::vertex_incident_patches), edge_is_feature_map);
 
-    return result;
+  return result;
 }
 
 //Convenient overrides
 template <typename PolygonMesh, typename EdgeIsFeatureMap, typename FT>
-void detect_sharp_edges(PolygonMesh& p,
+void detect_sharp_edges(const PolygonMesh& p,
                         FT angle_in_deg,
                         EdgeIsFeatureMap edge_is_feature_map)
 {
@@ -480,18 +489,16 @@ void detect_sharp_edges(PolygonMesh& p,
 template <typename PolygonMesh, typename FT,
           typename EdgeIsFeatureMap, typename PatchIdMap>
 typename boost::graph_traits<PolygonMesh>::faces_size_type
-sharp_edges_segmentation(PolygonMesh& p,
+sharp_edges_segmentation(const PolygonMesh& p,
                          FT angle_in_deg,
                          EdgeIsFeatureMap edge_is_feature_map,
                          PatchIdMap patch_id_map)
 {
   return sharp_edges_segmentation(p, angle_in_deg, edge_is_feature_map, patch_id_map,
-                                 parameters::all_default());
+                                  parameters::all_default());
 }
 
 } // end namespace PMP
 } // end namespace CGAL
 
-#include <CGAL/enable_warnings.h>
-
 #endif // CGAL_POLYGON_MESH_PROCESSING_DETECT_FEATURES_IN_POLYGON_MESH_H
