@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Corefinement/Face_graph_output_builder.h $
-// $Id: Face_graph_output_builder.h fa47c35 2021-03-03T08:28:28+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Corefinement/Face_graph_output_builder.h $
+// $Id: Face_graph_output_builder.h fd353e8 2021-03-03T17:18:11+01:00 Laurent Rineau
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -26,6 +26,7 @@
 #include <CGAL/Default.h>
 
 #include <boost/dynamic_bitset.hpp>
+#include <boost/mpl/has_xxx.hpp>
 
 // required to handle the multiple types of edge constrained maps
 // for the different output types. CGAL_COREF_FUNCTION_CALL_DEF
@@ -57,13 +58,72 @@ enum Boolean_operation_type {UNION = 0, INTERSECTION,
 namespace PMP=Polygon_mesh_processing;
 namespace params=PMP::parameters;
 
+// extra functions for handling non-documented functions for user visitors
+// with no extra functions
+BOOST_MPL_HAS_XXX_TRAIT_NAMED_DEF(Has_extra_functions,
+                                  Has_extra_functions,
+                                  false)
+
+template <class UserVisitor, class TriangleMesh, class FaceIndexMap>
+void export_flags(UserVisitor&, boost::mpl::bool_<false>,
+                  FaceIndexMap, const std::vector<std::size_t>&,
+                  const boost::dynamic_bitset<>&,
+                  const boost::dynamic_bitset<>&,
+                  const boost::dynamic_bitset<>&,
+                  const boost::dynamic_bitset<>&,
+                  TriangleMesh&)
+{}
+
+template <class UserVisitor, class halfedge_descriptor>
+void register_halfedge_pair(UserVisitor&, boost::mpl::bool_<false>,
+                            halfedge_descriptor, halfedge_descriptor,
+                            bool, bool,
+                            bool, bool,
+                            bool=false, bool=false,
+                            bool=false, bool=false)
+{}
+
+// with extra functions (forward the call to the visitor)
+template <class UserVisitor, class TriangleMesh, class FaceIndexMap>
+void export_flags(UserVisitor& visitor, boost::mpl::bool_<true>,
+                  FaceIndexMap fim, const std::vector<std::size_t>& tm_patch_ids,
+                  const boost::dynamic_bitset<>& is_patch_inside_other_tm,
+                  const boost::dynamic_bitset<>& coplanar_patches,
+                  const boost::dynamic_bitset<>& coplanar_patches_of_tm_for_union_and_intersection,
+                  const boost::dynamic_bitset<>& patch_status_not_set,
+                  TriangleMesh& tm)
+{
+  visitor.export_flags(fim, tm_patch_ids,
+                       is_patch_inside_other_tm,
+                       coplanar_patches,
+                       coplanar_patches_of_tm_for_union_and_intersection,
+                       patch_status_not_set,
+                       tm);
+}
+
+template <class UserVisitor, class halfedge_descriptor>
+void register_halfedge_pair(UserVisitor& visitor, boost::mpl::bool_<true>,
+                            halfedge_descriptor h1, halfedge_descriptor h2,
+                            bool q1_is_between_p1p2, bool q2_is_between_p1p2,
+                            bool p1_is_between_q1q2, bool p2_is_between_q1q2,
+                            bool p1_is_coplanar=false, bool p2_is_coplanar=false,
+                            bool q1_is_coplanar=false, bool q2_is_coplanar=false)
+{
+  visitor.register_halfedge_pair(h1, h2,
+                                 q1_is_between_p1p2, q2_is_between_p1p2,
+                                 p1_is_between_q1q2, p2_is_between_q1q2,
+                                 p1_is_coplanar, p2_is_coplanar,
+                                 q1_is_coplanar, q2_is_coplanar);
+}
+
+
 template <class TriangleMesh,
           class VertexPointMap1,
           class VertexPointMap2,
           class VpmOutTuple,
           class FaceIdMap1,
           class FaceIdMap2,
-          class Kernel_=Default,
+          class Kernel_ = Default,
           class EdgeMarkMapBind_  = Default,
           class EdgeMarkMapTuple_ = Default,
           class UserVisitor_      = Default>
@@ -86,6 +146,7 @@ class Face_graph_output_builder
                   No_mark<TriangleMesh> > >::type     EdgeMarkMapTuple;
   typedef typename Default::Get<
     UserVisitor_, Default_visitor<TriangleMesh> >::type  UserVisitor;
+  typedef typename Has_extra_functions<UserVisitor>::type VUNDF; //shortcut
 
 // graph_traits typedefs
   typedef TriangleMesh                                              TM;
@@ -458,8 +519,15 @@ public:
     const boost::dynamic_bitset<>& is_node_of_degree_one,
     const Mesh_to_map_node&)
   {
-    CGAL_assertion( vertex_to_node_id1.size() == vertex_to_node_id2.size());
-    CGAL_assertion( vertex_to_node_id1.size() == nodes.size());
+    const bool used_to_classify_patches =  requested_output[UNION]==boost::none &&
+                                           requested_output[TM1_MINUS_TM2]==boost::none &&
+                                           requested_output[TM2_MINUS_TM1]==boost::none &&
+                                           requested_output[INTERSECTION]==boost::none;
+
+    CGAL_assertion( vertex_to_node_id1.size() <= nodes.size() );
+    CGAL_assertion( vertex_to_node_id2.size() <= nodes.size() );
+    CGAL_assertion(used_to_classify_patches || vertex_to_node_id1.size() == vertex_to_node_id2.size());
+    CGAL_assertion(used_to_classify_patches || vertex_to_node_id1.size() == nodes.size());
 
     Intersection_edge_map& intersection_edges1 = mesh_to_intersection_edges[&tm1];
     Intersection_edge_map& intersection_edges2 = mesh_to_intersection_edges[&tm2];
@@ -479,10 +547,6 @@ public:
     }
     CGAL_assertion(BGL::internal::is_index_map_valid(fids2, num_faces(tm2), faces(tm2)));
 
-    // bitset to identify coplanar faces
-    boost::dynamic_bitset<> tm1_coplanar_faces(num_faces(tm1), 0);
-    boost::dynamic_bitset<> tm2_coplanar_faces(num_faces(tm2), 0);
-
     // In the following loop we filter intersection edges that are strictly inside a patch
     // of coplanar facets so that we keep only the edges on the border of the patch.
     // This is not optimal and in an ideal world being able to find the outside edges
@@ -495,11 +559,21 @@ public:
                                        : epp_it_end;
     boost::unordered_set<edge_descriptor> inter_edges_to_remove1,
                                           inter_edges_to_remove2;
+
+    // Each vector contains a subset of coplanar faces. More particularly only
+    // the coplanar faces incident to an intersection edge. Note
+    // that for coplanar faces, intersection edges are on the input
+    // edges and some coplanar faces might not be seen as they are
+    // the result of the retriangulation.
+    std::vector<face_descriptor> tm1_coplanar_faces, tm2_coplanar_faces;
+
     for (;epp_it!=epp_it_end;)
     {
       halfedge_descriptor h1  = epp_it->second.first[&tm1];
+      CGAL_assertion( h1 != GT::null_halfedge());
       halfedge_descriptor h1_opp = opposite(h1, tm1);
       halfedge_descriptor h2 = epp_it->second.first[&tm2];
+      CGAL_assertion( h2 != GT::null_halfedge());
       halfedge_descriptor h2_opp = opposite(h2, tm2);
 
       //vertices from tm1
@@ -514,7 +588,7 @@ public:
       Node_id index_q2 = get_node_id(q2, vertex_to_node_id2);
 
       // set boolean for the position of p1 wrt to q1 and q2
-      bool p1_eq_q1=is_border(h1_opp, tm1), p1_eq_q2=p1_eq_q1;
+      bool p1_eq_q1 = false, p1_eq_q2 = false;
       if (!is_border(h1_opp, tm1) && index_p1!=NID)
       {
         if (!is_border(h2_opp, tm2))
@@ -523,8 +597,8 @@ public:
           if (p1_eq_q1)
           {
             //mark coplanar facets if any
-            tm1_coplanar_faces.set(get(fids1, face(h1_opp, tm1)));
-            tm2_coplanar_faces.set(get(fids2, face(h2_opp, tm2)));
+            tm1_coplanar_faces.push_back(face(h1_opp, tm1));
+            tm2_coplanar_faces.push_back(face(h2_opp, tm2));
           }
         }
         if (!is_border(h2, tm2))
@@ -533,14 +607,14 @@ public:
           if (p1_eq_q2)
           {
             //mark coplanar facets if any
-            tm1_coplanar_faces.set(get(fids1, face(h1_opp, tm1)));
-            tm2_coplanar_faces.set(get(fids2, face(h2, tm2)));
+            tm1_coplanar_faces.push_back(face(h1_opp, tm1));
+            tm2_coplanar_faces.push_back(face(h2, tm2));
           }
         }
       }
 
       // set boolean for the position of p2 wrt to q1 and q2
-      bool p2_eq_q1=is_border(h1, tm1), p2_eq_q2=p2_eq_q1;
+      bool p2_eq_q1 = false, p2_eq_q2 = false;
       if (!is_border(h1, tm1) && index_p2!=NID)
       {
         if (!is_border(h2_opp, tm2))
@@ -548,8 +622,8 @@ public:
           p2_eq_q1 = index_p2 == index_q1;
           if (p2_eq_q1){
             //mark coplanar facets if any
-            tm1_coplanar_faces.set(get(fids1, face(h1, tm1)));
-            tm2_coplanar_faces.set(get(fids2, face(h2_opp, tm2)));
+            tm1_coplanar_faces.push_back(face(h1, tm1));
+            tm2_coplanar_faces.push_back(face(h2_opp, tm2));
           }
         }
         if (!is_border(h2, tm2))
@@ -557,8 +631,8 @@ public:
           p2_eq_q2 = index_p2 == index_q2;
           if (p2_eq_q2){
             //mark coplanar facets if any
-            tm1_coplanar_faces.set(get(fids1, face(h1, tm1)));
-            tm2_coplanar_faces.set(get(fids2, face(h2, tm2)));
+            tm1_coplanar_faces.push_back(face(h1, tm1));
+            tm2_coplanar_faces.push_back(face(h2, tm2));
           }
         }
       }
@@ -671,6 +745,21 @@ public:
     patch_status_not_set_tm1.set();
     patch_status_not_set_tm2.set();
 
+    // first set coplanar status of patches using the coplanar faces collected during the
+    // extra intersection edges collected. This is important in the case of full connected components
+    // being coplanar. They have no intersection edges (closed cc) or only intersection edges on the
+    // boundary (non-closed cc)
+    for (face_descriptor f1 : tm1_coplanar_faces)
+    {
+      std::size_t fid1 = get(fids1, f1);
+      coplanar_patches_of_tm1.set(tm1_patch_ids[ fid1 ]);
+    }
+    for (face_descriptor f2 : tm2_coplanar_faces)
+    {
+      std::size_t fid2 = get(fids2, f2);
+      coplanar_patches_of_tm2.set(tm2_patch_ids[ fid2 ]);
+    }
+
     for (typename An_edge_per_polyline_map::iterator
             it=an_edge_per_polyline.begin(),
             it_end=an_edge_per_polyline.end(); it!=it_end;++it)
@@ -703,38 +792,82 @@ public:
           if ( is_border(h1,tm1) != is_border(h2,tm2) )
           {
             //No restriction at this level
-            std::size_t patch_id1 =
-              tm1_patch_ids[ get( fids1, is_border(h1,tm1)
-                                            ? face(opposite(h1,tm1),tm1)
-                                            : face(h1,tm1)) ];
-            std::size_t patch_id2 =
-              tm2_patch_ids[ get( fids2, is_border(h2,tm2)
-                                            ? face(opposite(h2,tm2),tm2)
-                                            : face(h2,tm2)) ];
-            patch_status_not_set_tm1.reset(patch_id1);
-            patch_status_not_set_tm2.reset(patch_id2);
+            std::size_t fid1 =
+              get(fids1, is_border(h1,tm1) ? face(opposite(h1,tm1),tm1)
+                                           : face(h1,tm1));
+            std::size_t fid2 =
+               get(fids2, is_border(h2,tm2) ? face(opposite(h2,tm2),tm2)
+                                            : face(h2,tm2));
+            std::size_t patch_id_p=tm1_patch_ids[ fid1 ];
+            std::size_t patch_id_q=tm2_patch_ids[ fid2 ];
+
+            patch_status_not_set_tm1.reset(patch_id_p);
+            patch_status_not_set_tm2.reset(patch_id_q);
           }
           else
           {
-            //Nothing allowed
             if (!used_to_clip_a_surface)
             {
+              if (used_to_classify_patches)
+              {
+                Node_id index_o_prime = ids.first, index_o = ids.second;
+                if( is_border(h1, tm1) )
+                {
+                  h1 = opposite(h1, tm1);
+                  h2 = opposite(h2, tm2);
+                  std::swap(index_o_prime, index_o);
+                }
+
+                std::size_t fid1 = get(fids1, face(h1,tm1));
+                std::size_t fid2 = get(fids2, face(h2,tm2));
+                std::size_t patch_id_p=tm1_patch_ids[ fid1 ];
+                std::size_t patch_id_q=tm2_patch_ids[ fid2 ];
+
+                //indicates that patch status will be updated
+                patch_status_not_set_tm1.reset(patch_id_p);
+                patch_status_not_set_tm2.reset(patch_id_q);
+
+                if (coplanar_patches_of_tm1.test(patch_id_p) && coplanar_patches_of_tm2.test(patch_id_q))
+                {
+                  coplanar_patches_of_tm1_for_union_and_intersection.set(patch_id_p);
+                  coplanar_patches_of_tm2_for_union_and_intersection.set(patch_id_q);
+                }
+                else
+                {
+                  vertex_descriptor p = target(next(h1,tm1),tm1);
+                  vertex_descriptor q = target(next(h2,tm2),tm2);
+                  Node_id index_p = get_node_id(p, vertex_to_node_id1);
+                  Node_id index_q = get_node_id(q, vertex_to_node_id2);
+
+                  if ( p_is_below_q(index_o_prime, index_o,
+                                    index_p, index_q, p, q,
+                                    vpm1, vpm2,
+                                    nodes) )
+                    is_patch_inside_tm2.set(patch_id_p);
+                  else
+                    is_patch_inside_tm1.set(patch_id_q);
+                }
+              }
+              else
+              {
+                //Nothing allowed
 #ifdef CGAL_COREFINEMENT_DEBUG
-              std::cout << "  Non-manifold edge case 1\n";
+                std::cout << "  Non-manifold edge case 1\n";
 #endif
-              impossible_operation.set();
-              return;
+                impossible_operation.set();
+                return;
+              }
             }
           }
         }
         else
         {
-          //Ambiguous, we can do nothing
-          if (!used_to_clip_a_surface)
+          if (!used_to_clip_a_surface && !used_to_classify_patches)
           {
 #ifdef CGAL_COREFINEMENT_DEBUG
               std::cout << "  Non-manifold edge case 2\n";
 #endif
+            //Ambiguous, we can do nothing
             impossible_operation.set();
             return;
           }
@@ -766,20 +899,38 @@ public:
             std::size_t patch_id_q1=tm2_patch_ids[ get(fids2, face(opposite(h2,tm2),tm2)) ];
             std::size_t patch_id_q2=tm2_patch_ids[ get(fids2, face(h2,tm2)) ];
 
-            //indicates that patch status will be updated
-            patch_status_not_set_tm1.reset(patch_id_p);
-            patch_status_not_set_tm2.reset(patch_id_q1);
-            patch_status_not_set_tm2.reset(patch_id_q2);
+            if (index_p!=index_q1 && index_p!=index_q2)
+            {
+              //indicates that patch status will be updated
+              patch_status_not_set_tm1.reset(patch_id_p);
+              patch_status_not_set_tm2.reset(patch_id_q1);
+              patch_status_not_set_tm2.reset(patch_id_q2);
 
-            bool p_is_between_q1q2 = sorted_around_edge(
-                ids.first, ids.second,
-                index_q1, index_q2, index_p,
-                q1, q2, p,
-                vpm2, vpm1,
-                nodes);
+              bool p_is_between_q1q2 = sorted_around_edge(
+                  ids.first, ids.second,
+                  index_q1, index_q2, index_p,
+                  q1, q2, p,
+                  vpm2, vpm1,
+                  nodes);
 
-            if (p_is_between_q1q2)
-              is_patch_inside_tm2.set(patch_id_p);
+              if (p_is_between_q1q2)
+              {
+                is_patch_inside_tm2.set(patch_id_p);
+                // locally does not really make sense globally
+                if (h == h1) // i.e. p2
+                  is_patch_inside_tm1.set(patch_id_q2);
+                else
+                  is_patch_inside_tm1.set(patch_id_q1);
+              }
+              else
+              {
+                // locally does not really make sense globally
+                if (h == h1) // i.e. p2
+                  is_patch_inside_tm1.set(patch_id_q1);
+                else
+                  is_patch_inside_tm1.set(patch_id_q2);
+              }
+            }
           }
         }
       }
@@ -787,12 +938,75 @@ public:
         if ( is_border_edge(h2,tm2) )
         {
           CGAL_assertion(!used_to_clip_a_surface);
-          //Ambiguous, we do nothing
+          if (!used_to_classify_patches)
+          {
 #ifdef CGAL_COREFINEMENT_DEBUG
-              std::cout << "  Non-manifold edge case 3\n";
+            std::cout << "  Non-manifold edge case 3\n";
 #endif
-          impossible_operation.set();
-          return;
+            impossible_operation.set();
+            return;
+          }
+          else
+          {
+            //Sort the three triangle faces around their common edge
+            //  we assume that the exterior of the volume is indicated by
+            //  counterclockwise oriented faces
+            //  (corrected by is_tmi_inside_tmi).
+            halfedge_descriptor h = is_border(h2, tm2) ? opposite(h2, tm2) : h2;
+            vertex_descriptor q = target(next(h,tm2),tm2);
+            //    when looking from the side of indices.second,
+            //    the interior of the first triangle mesh is described
+            //    by turning counterclockwise from p1 to p2
+            vertex_descriptor p1=target(next(opposite(h1,tm1),tm1),tm1);
+            vertex_descriptor p2=target(next(h1,tm1),tm1);
+            //    when looking from the side of indices.second,
+            //    the interior of the second volume is described
+            //    by turning from p1 to p2
+
+            //check if the third point of each triangular face is an original point (stay NID)
+            //or a intersection point (in that case we need the index of the corresponding node to
+            //have the exact value of the point)
+            Node_id index_q = get_node_id(q, vertex_to_node_id2);
+            Node_id index_p1 = get_node_id(p1, vertex_to_node_id1);
+            Node_id index_p2 = get_node_id(p2, vertex_to_node_id1);
+
+            std::size_t patch_id_q=tm2_patch_ids[ get(fids2, face(h,tm2)) ];
+            std::size_t patch_id_p1=tm1_patch_ids[ get(fids1, face(opposite(h1,tm1),tm1)) ];
+            std::size_t patch_id_p2=tm1_patch_ids[ get(fids1, face(h1,tm1)) ];
+
+            if (index_q!=index_p1 && index_q!=index_p2)
+            {
+              //indicates that patch status will be updated
+              patch_status_not_set_tm2.reset(patch_id_q);
+              patch_status_not_set_tm1.reset(patch_id_p1);
+              patch_status_not_set_tm1.reset(patch_id_p2);
+
+              bool q_is_between_p1p2 = sorted_around_edge(
+                  ids.first, ids.second,
+                  index_p1, index_p2, index_q,
+                  p1, p2, q,
+                  vpm1, vpm2,
+                  nodes);
+
+              if (q_is_between_p1p2)
+              {
+                is_patch_inside_tm1.set(patch_id_q);
+                // locally does not really make sense globally
+                if (h == h2) // i.e. q2
+                  is_patch_inside_tm2.set(patch_id_p2);
+                else
+                  is_patch_inside_tm2.set(patch_id_p1);
+              }
+              else
+              {
+                // locally does not really make sense globally
+                if (h == h2) // i.e. q2
+                  is_patch_inside_tm2.set(patch_id_p1);
+                else
+                  is_patch_inside_tm2.set(patch_id_p2);
+              }
+            }
+          }
         }
         else
         {
@@ -861,6 +1075,12 @@ public:
               p1, p2, q2,
               vpm1, vpm2,
               nodes);
+
+            register_halfedge_pair(user_visitor, VUNDF(),
+                                   h1, h2,
+                                   false, q2_is_between_p1p2, false, !q2_is_between_p1p2,
+                                   true, false, true, false);
+
             if ( q2_is_between_p1p2 ) is_patch_inside_tm1.set(patch_id_q2); //case 1
             else is_patch_inside_tm2.set(patch_id_p2); //case 2
             continue;
@@ -873,7 +1093,7 @@ public:
                    vpm1, vpm2,
                    nodes) ) //p1==q2
             {
-              CGAL_assertion( index_p1!=index_p2 || index_p1==Node_id((std::numeric_limits<Node_id>::max)()) );
+              CGAL_assertion( index_p1!=index_p2 || index_p1==NID );
               coplanar_patches_of_tm1.set(patch_id_p1);
               coplanar_patches_of_tm2.set(patch_id_q2);
               bool q1_is_between_p1p2 = sorted_around_edge(
@@ -882,6 +1102,12 @@ public:
                 p1, p2, q1,
                 vpm1, vpm2,
                 nodes);
+
+              register_halfedge_pair(user_visitor, VUNDF(),
+                                     h1, h2,
+                                     q1_is_between_p1p2, false, false, !q1_is_between_p1p2,
+                                     true, false, false, true);
+
               if ( q1_is_between_p1p2 )
               { // case 3
                 is_patch_inside_tm1.set(patch_id_q1);
@@ -906,6 +1132,12 @@ public:
                   p1, p2, q2,
                   vpm1, vpm2,
                   nodes);
+
+                register_halfedge_pair(user_visitor, VUNDF(),
+                                       h1, h2,
+                                       false, q2_is_between_p1p2, !q2_is_between_p1p2, false,
+                                       false, true, true, false);
+
                 if ( q2_is_between_p1p2 )
                 {  //case 5
                   is_patch_inside_tm1.set(patch_id_q2);
@@ -931,6 +1163,12 @@ public:
                     p1, p2, q1,
                     vpm1, vpm2,
                     nodes);
+
+                  register_halfedge_pair(user_visitor, VUNDF(),
+                                         h1, h2,
+                                         q1_is_between_p1p2, false, !q1_is_between_p1p2, false,
+                                         false, true, false, true);
+
                   if ( q1_is_between_p1p2 ) is_patch_inside_tm1.set(patch_id_q1);  //case 7
                   else is_patch_inside_tm2.set(patch_id_p1); //case 8
                   continue;
@@ -943,17 +1181,17 @@ public:
 #endif //CGAL_COREFINEMENT_POLYHEDRA_DEBUG
 
           CGAL_assertion(
-              ( index_p1 == Node_id((std::numeric_limits<Node_id>::max)()) ? nodes.to_exact(get(vpm1,p1)): nodes.exact_node(index_p1) ) !=
-              ( index_q1 == Node_id((std::numeric_limits<Node_id>::max)()) ? nodes.to_exact(get(vpm2,q1)): nodes.exact_node(index_q1) )
+              ( index_p1 == NID ? nodes.to_exact(get(vpm1,p1)): nodes.exact_node(index_p1) ) !=
+              ( index_q1 == NID ? nodes.to_exact(get(vpm2,q1)): nodes.exact_node(index_q1) )
           &&
-              ( index_p2 == Node_id((std::numeric_limits<Node_id>::max)()) ? nodes.to_exact(get(vpm1,p2)): nodes.exact_node(index_p2) ) !=
-              ( index_q1 == Node_id((std::numeric_limits<Node_id>::max)()) ? nodes.to_exact(get(vpm2,q1)): nodes.exact_node(index_q1) )
+              ( index_p2 == NID ? nodes.to_exact(get(vpm1,p2)): nodes.exact_node(index_p2) ) !=
+              ( index_q1 == NID ? nodes.to_exact(get(vpm2,q1)): nodes.exact_node(index_q1) )
           &&
-              ( index_p1 == Node_id((std::numeric_limits<Node_id>::max)()) ? nodes.to_exact(get(vpm1,p1)): nodes.exact_node(index_p1) ) !=
-              ( index_q2 == Node_id((std::numeric_limits<Node_id>::max)()) ? nodes.to_exact(get(vpm2,q2)): nodes.exact_node(index_q2) )
+              ( index_p1 == NID ? nodes.to_exact(get(vpm1,p1)): nodes.exact_node(index_p1) ) !=
+              ( index_q2 == NID ? nodes.to_exact(get(vpm2,q2)): nodes.exact_node(index_q2) )
           &&
-              ( index_p2 == Node_id((std::numeric_limits<Node_id>::max)()) ? nodes.to_exact(get(vpm1,p2)): nodes.exact_node(index_p2) ) !=
-              ( index_q2 == Node_id((std::numeric_limits<Node_id>::max)()) ? nodes.to_exact(get(vpm2,q2)): nodes.exact_node(index_q2) )
+              ( index_p2 == NID ? nodes.to_exact(get(vpm1,p2)): nodes.exact_node(index_p2) ) !=
+              ( index_q2 == NID ? nodes.to_exact(get(vpm2,q2)): nodes.exact_node(index_q2) )
           );
 
           bool q1_is_between_p1p2 = sorted_around_edge(
@@ -981,6 +1219,7 @@ public:
                 vpm2, vpm1,
                 nodes);
               if (!p1_is_between_q1q2){
+                register_halfedge_pair(user_visitor, VUNDF(), h1, h2, true, true, false, false);
                 // case (a4)
                 // poly_first  - poly_second            = p1q1 U q2p2
                 // poly_second - poly_first             = {0}
@@ -992,6 +1231,7 @@ public:
                 impossible_operation.set(TM1_MINUS_TM2); // tm1-tm2 is non-manifold
               }
               else{
+                register_halfedge_pair(user_visitor, VUNDF(), h1, h2, true, true, true, true);
                 // case (b4)
                 // poly_first  - poly_second            = q2q1
                 // poly_second - poly_first             = p2p1
@@ -1010,6 +1250,7 @@ public:
             }
             else
             {
+              register_halfedge_pair(user_visitor, VUNDF(), h1, h2, true, false, false, true);
               //case (c4)
               // poly_first  - poly_second            = p1q1
               // poly_second - poly_first             = p2q2
@@ -1034,6 +1275,7 @@ public:
           {
             if( q2_is_between_p1p2 )
             {
+              register_halfedge_pair(user_visitor, VUNDF(), h1, h2, false, true, true, false);
               //case (d4)
               // poly_first  - poly_second            = q2p2
               // poly_second - poly_first             = q1p1
@@ -1063,6 +1305,7 @@ public:
                 vpm2, vpm1,
                 nodes);
               if (!p1_is_between_q1q2){
+                register_halfedge_pair(user_visitor, VUNDF(), h1, h2, false, false, false, false);
                 //case (e4)
                 // poly_first  - poly_second            = p1p2
                 // poly_second - poly_first             = q1q2
@@ -1074,6 +1317,7 @@ public:
                 impossible_operation.set(UNION); // tm1 U tm2 is non-manifold
               }
               else{
+                register_halfedge_pair(user_visitor, VUNDF(), h1, h2, false, false, true, true);
                 //case (f4)
                 is_patch_inside_tm2.set(patch_id_p1);
                 is_patch_inside_tm2.set(patch_id_p2);
@@ -1091,6 +1335,24 @@ public:
         }
     }
 
+    if (used_to_classify_patches)
+    {
+      export_flags( user_visitor, VUNDF(),fids1, tm1_patch_ids,
+                    is_patch_inside_tm2,
+                    coplanar_patches_of_tm1,
+                    coplanar_patches_of_tm1_for_union_and_intersection,
+                    patch_status_not_set_tm1,
+                    tm1);
+      export_flags( user_visitor, VUNDF(),
+                    fids2, tm2_patch_ids,
+                    is_patch_inside_tm1,
+                    coplanar_patches_of_tm2,
+                    coplanar_patches_of_tm2_for_union_and_intersection,
+                    patch_status_not_set_tm2,
+                    tm2);
+      return;
+    }
+
     // (2-b) Classify isolated surface patches wrt the other mesh
     // in case a mesh is not closed, any cc of the second mesh that is
     // free from intersection is considered as outside/inside
@@ -1146,10 +1408,10 @@ public:
 
           if (index_p1 != NID)
           {
-            if (tm1_coplanar_faces.test(f_id))
+            if (coplanar_patches_of_tm1.test(patch_id))
             {
-              coplanar_patches_of_tm1.set(patch_id);
-              coplanar_patches_of_tm1_for_union_and_intersection.set(patch_id);
+              if (is_tm1_inside_out == is_tm2_inside_out)
+                coplanar_patches_of_tm1_for_union_and_intersection.set(patch_id);
             }
             else
             {
@@ -1220,10 +1482,10 @@ public:
           }
           if (index_p2 != NID)
           {
-            if (tm2_coplanar_faces.test(f_id))
+            if (coplanar_patches_of_tm2.test(patch_id))
             {
-              coplanar_patches_of_tm2.set(patch_id);
-              coplanar_patches_of_tm2_for_union_and_intersection.set(patch_id);
+              if (is_tm1_inside_out == is_tm2_inside_out)
+                coplanar_patches_of_tm2_for_union_and_intersection.set(patch_id);
             }
             else
             {
