@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Shape_detection/include/CGAL/Shape_detection/Efficient_RANSAC/Shape_base.h $
-// $Id: Shape_base.h a7b2ed1 2020-12-15T15:44:11+01:00 Simon Giraudot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Shape_detection/include/CGAL/Shape_detection/Efficient_RANSAC/Shape_base.h $
+// $Id: Shape_base.h ae8ec55 2021-01-19T09:54:58+01:00 Simon Giraudot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -36,10 +36,6 @@
 
 namespace CGAL {
   namespace Shape_detection {
-  namespace internal {
-    template<class PointAccessor>
-    class Octree;
-  }
 
     /*!
      \ingroup PkgShapeDetectionRANSACShapes
@@ -56,8 +52,6 @@ namespace CGAL {
     friend class Efficient_RANSAC;
     template <class T>
     friend class Region_growing_depr;
-    template<class PointAccessor>
-    friend class internal::Octree;
     /// \endcond
 
   public:
