@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.3/Triangulation/include/CGAL/Triangulation.h $
-// $Id: Triangulation.h f8fd7a6 2020-04-18T13:53:46+02:00 Marc Glisse
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Triangulation/include/CGAL/Triangulation.h $
+// $Id: Triangulation.h 98e4718 2021-08-26T11:33:39+02:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)    : Samuel Hornus
@@ -16,7 +16,7 @@
 
 #include <CGAL/disable_warnings.h>
 
-#include <CGAL/internal/Triangulation/utilities.h>
+#include <CGAL/Triangulation/internal/utilities.h>
 #include <CGAL/Triangulation_data_structure.h>
 #include <CGAL/Triangulation_full_cell.h>
 #include <CGAL/Triangulation_vertex.h>
@@ -1336,7 +1336,7 @@ operator>>(std::istream & is, Triangulation<TT, TDS> & tr)
     // read current dimension and number of vertices
     size_t n;
     int cd;
-    if( is_ascii(is) )
+    if( IO::is_ascii(is) )
         is >> cd >> n;
     else
     {
@@ -1388,7 +1388,7 @@ operator<<(std::ostream & os, const Triangulation<TT, TDS> & tr)
 
     // outputs dimensions and number of vertices
     size_t n = tr.number_of_vertices();
-    if( is_ascii(os) )
+    if( IO::is_ascii(os) )
         os << tr.current_dimension() << std::endl << n << std::endl;
     else
     {
@@ -1405,7 +1405,7 @@ operator<<(std::ostream & os, const Triangulation<TT, TDS> & tr)
 
     // infinite vertex has index 0 (among all the vertices)
     index_of_vertex[tr.infinite_vertex()] = i++;
-    if(is_ascii(os))
+    if(IO::is_ascii(os))
       os << *tr.infinite_vertex() <<"\n";
     else
       write(os, *tr.infinite_vertex());
@@ -1414,7 +1414,7 @@ operator<<(std::ostream & os, const Triangulation<TT, TDS> & tr)
     {
         if( tr.is_infinite(it) )
             continue;
-        if(is_ascii(os))
+        if(IO::is_ascii(os))
           os << *it <<"\n"; // write the vertex
         else
           write(os, *it);
