@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.3/Polyhedron/include/CGAL/boost/graph/properties_Polyhedron_3_time_stamp.h $
-// $Id: properties_Polyhedron_3_time_stamp.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Polyhedron/include/CGAL/boost/graph/properties_Polyhedron_3_time_stamp.h $
+// $Id: properties_Polyhedron_3_time_stamp.h df56098 2021-10-08T12:13:43+02:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -33,8 +33,7 @@ std::size_t get(Polyhedron_face_time_stamp_pmap, Handle_type h)
 }
 
 template <typename Handle_type>
-void put(Polyhedron_face_time_stamp_pmap, Handle_type h,
-         std::size_t ts)
+void put(Polyhedron_face_time_stamp_pmap, Handle_type h, std::size_t ts)
 {
   h->set_time_stamp(ts);
 }
